@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.cpp,v 1.22 2006/09/13 15:46:46 vkurland Exp $
+  $Id: ActionsDialog.cpp,v 1.23 2006/10/24 03:43:24 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -223,7 +223,7 @@ void ActionsDialog::setRule(PolicyRule *r )
     // ROUTE action:
 
     // build a map for combobox so visible combobox items can be localized
-    QStringList route_options = getRouteOptions( platform.c_str() );
+    QStringList route_options = getRouteOptions_pf_ipf( platform.c_str() );
 
     // iptables
     data.registerOption ( ipt_iif             , ropt , "ipt_iif" );
