@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: CustomServiceDialog.cpp,v 1.16 2004/12/01 07:44:52 vkurland Exp $
+  $Id: CustomServiceDialog.cpp,v 1.20 2006/05/31 03:27:23 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,6 +31,7 @@
 #include "FWBTree.h"
 #include "CustomServiceDialog.h"
 #include "ObjectManipulator.h"
+#include "FWBSettings.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/CustomService.h"
@@ -63,6 +64,7 @@ void CustomServiceDialog::loadFWObject(FWObject *o)
     platform->clear();
 
     int cp=0;
+    showPlatform=st->readEntry("/FirewallBuilder2/CustomService/Platform");
     QMap<QString,QString> platforms = getAllPlatforms();
     QMap<QString,QString>::iterator i;
     for (i=platforms.begin(); i!=platforms.end(); i++,cp++)
@@ -82,7 +84,7 @@ void CustomServiceDialog::loadFWObject(FWObject *o)
 
     code->setText( QString::fromUtf8(allCodes[showPlatform] ));
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -109,7 +111,9 @@ void CustomServiceDialog::changed()
         QString  pl   = platformReverseMap[platform->currentText()];
         allCodes[pl] = code->text().utf8();
 
-        apply->setEnabled( true );
+        //apply->setEnabled( true );
+        emit changed_sign();
+
     }
 }
 
@@ -120,7 +124,7 @@ void CustomServiceDialog::validate(bool *res)
 
 void CustomServiceDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void CustomServiceDialog::libChanged()
@@ -134,6 +138,7 @@ void CustomServiceDialog::platformChanged()
     QString npl = platformReverseMap[platform->currentText()];
     code->setText( QString::fromUtf8(allCodes[ npl ]) );
     showPlatform = npl;
+    st->writeEntry("/FirewallBuilder2/CustomService/Platform",showPlatform);
     init=false;
 //    changed();
 }
@@ -170,7 +175,8 @@ void CustomServiceDialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void CustomServiceDialog::discardChanges()
