@@ -262,4 +262,52 @@ void FWBMainWindow_q::fileDiscard()
 void FWBMainWindow_q::fileCommit()
 {
 
+}
+
+void FWBMainWindow_q::lockObject()
+{
+
+}
+
+
+void FWBMainWindow_q::unlockObject()
+{
+
+}
+
+
+void FWBMainWindow_q::prepareObjectMenu()
+{
+
+}
+
+
+void FWBMainWindow_q::toolsDiscoveryDruid()
+{
+
+}
+
+
+void FWBMainWindow_q::objectFind()
+{
+
+}
+
+
+
+void FWBMainWindow_q::showNextSearchResult()
+{
+
+}
+
+
+void FWBMainWindow_q::closeAuxiliaryPanel()
+{
+
+}
+
+
+void FWBMainWindow_q::ruleSetTabChanged(QWidget*)
+{
+
 }
\ No newline at end of file
