@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.cpp,v 1.49 2006/07/23 02:37:01 vkurland Exp $
+  $Id: FWObjectPropertiesFactory.cpp,v 1.50 2006/10/24 03:43:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -541,7 +541,7 @@ QString FWObjectPropertiesFactory::getRuleActionProperties(PolicyRule *rule)
                     {
                         par = par + " "+ 
                             getScreenName(a.c_str(),
-                                          getRouteOptions( platform.c_str() ));
+                                          getRouteOptions_pf_ipf( platform.c_str() ));
                     }
                     a = ropt->getStr("ipf_route_opt_if");
                     if (!a.empty()) par = par + " "+ a.c_str();
