@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp,v 1.211 2006/10/22 04:39:36 vkurland Exp $
+  $Id: FWWindow.cpp,v 1.212 2006/11/10 05:24:48 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1855,6 +1855,14 @@ void FWWindow::addPolicyBranchTab(PolicyRule *rule)
         ruleSetViews[subset]=rsv;
     }
     setPolicyBranchTabName(rule);
+
+    for (FWObject::iterator i=subset->begin(); i!=subset->end(); i++)
+    {
+        PolicyRule *srule = PolicyRule::cast(*i);
+        if (srule->getAction() == PolicyRule::Branch)
+            addPolicyBranchTab(srule);
+    }
+
 }
 
 void FWWindow::removePolicyBranchTab(PolicyRule *rule)
