@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.h,v 1.73 2006/07/14 06:06:42 vkurland Exp $
+  $Id: FWWindow.h,v 1.77 2006/09/11 00:41:09 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,6 +31,7 @@
 #include "ObjectEditor.h"
 #include "RCS.h"
 #include "FindObjectWidget.h"
+#include "FindWhereUsedWidget.h"
 
 #include "fwbuilder/FWObject.h"
 
@@ -59,6 +60,10 @@ class FWWindow : public FWBMainWindow_q {
     bool                                    editingStandardLib;
     bool                                    editingTemplateLib;
     bool                                    changingTabs;
+    bool                                    safeMode;
+    bool                                    ruleSetRedrawPending;
+
+    QString                                 startupFileName;
 
     std::vector<libfwbuilder::FWObject*>    firewalls;
     std::map<libfwbuilder::FWObject*, RuleSetView*> ruleSetViews;
@@ -69,13 +74,16 @@ class FWWindow : public FWBMainWindow_q {
     libfwbuilder::FWObject                 *shownInInfo;
 
     QWidget                                *editorOwner;
+    QWidget                                *instd;
     
     QTimer                                 *autosaveTimer;
+    QTimer                                 *instDialogOnScreenTimer;
     QString                                 noFirewalls;
     QPrinter                               *printer;
     libfwbuilder::FWObject                 *searchObject;
     libfwbuilder::FWObject                 *replaceObject;
     int                                    lastFirewallIdx;
+
     void clearFirewallTabs();
     
  public slots:
@@ -84,6 +92,7 @@ class FWWindow : public FWBMainWindow_q {
 
      virtual void openFirewall( int idx );
      virtual void reopenFirewall();
+     virtual void redrawRuleSets();
      virtual void deleteFirewall(libfwbuilder::FWObject *fw);
      virtual void changeInfoStyle();
      virtual void ruleSetTabChanged(QWidget* w);
@@ -108,6 +117,8 @@ class FWWindow : public FWBMainWindow_q {
      virtual void editPaste();
      virtual void editPrefs();
 
+     virtual void startupLoad();
+
      virtual void helpAbout();
      virtual void debug();
      
@@ -140,11 +151,14 @@ class FWWindow : public FWBMainWindow_q {
      virtual void rollBackSelectionSameWidget();
      virtual void rollBackSelectionDifferentWidget();
 
+     virtual void killInstDialog();
+
  signals:
      void restoreSelection_sign(bool same_widget);
 
  public:
     FindObjectWidget *findObjectWidget;
+    FindWhereUsedWidget *findWhereUsedWidget;
     
     FWWindow();
     ~FWWindow();
@@ -157,7 +171,7 @@ class FWWindow : public FWBMainWindow_q {
     void loadLibrary(const std::string &libfpath);
     void save();
     bool checkin(bool unlock);
-    void showFirewalls();
+    void showFirewalls(bool open_first_firewall=true);
     void showFirewall(libfwbuilder::FWObject *f);
     void addFirewallToList(libfwbuilder::FWObject *f);
     void removeFirewallFromList(libfwbuilder::FWObject *f);
@@ -172,6 +186,8 @@ class FWWindow : public FWBMainWindow_q {
     void setFileName(const QString &fname);
     
     bool saveIfModified();
+
+    void showFirewallRuleSets( libfwbuilder::FWObject *fw );
     
     void updateFirewallName(libfwbuilder::FWObject *obj,const QString &oldName);
     void updateRuleSetView();
@@ -196,6 +212,7 @@ class FWWindow : public FWBMainWindow_q {
 
     void setupAutoSave();
     void findObject(libfwbuilder::FWObject *);
+    void findWhereUsed(libfwbuilder::FWObject *);
     RuleSetView* getRuleSetViews(libfwbuilder::FWObject *o) 
     {return ruleSetViews[o];};
 
@@ -221,7 +238,11 @@ class FWWindow : public FWBMainWindow_q {
                        libfwbuilder::FWObject *root,
                        std::list<libfwbuilder::FWReference*> &extRefs);
     
-    
+    void setSafeMode(bool f) { safeMode=f; }
+    void setStartupFileName(const QString &fn) { startupFileName = fn; }
+
+    void scheduleRuleSetRedraw();
+
  protected:
 
     virtual void showEvent( QShowEvent *ev);
