@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindowPrint.cpp,v 1.22 2006/02/20 17:05:41 vkurland Exp $
+  $Id: FWWindowPrint.cpp,v 1.23 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,6 +52,7 @@
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qcolor.h>
+#include <qpixmapcache.h>
 
 #include "fwbuilder/Policy.h"
 #include "fwbuilder/InterfacePolicy.h"
@@ -192,8 +193,17 @@ int addObjectsToTable(list<FWObject*> &objects,
         if (Interval::cast(*i)!=NULL && Interval::cast(*i)->isAny()) continue;
 
         string typeName = (*i)->getTypeName();
-        QPixmap pm = QPixmap::fromMimeSource( Resources::global_res->getResourceStr(
-                                                  icon_path+typeName+"/icon").c_str());
+//        QPixmap pm = QPixmap::fromMimeSource( Resources::global_res->getResourceStr(
+//                                                icon_path+typeName+"/icon").c_str());
+
+        QString icn = Resources::global_res->getResourceStr(
+            icon_path+typeName+"/icon").c_str();
+        QPixmap pm;
+        if ( ! QPixmapCache::find( icn, pm) )
+        {
+            pm = QPixmap::fromMimeSource( icn );
+            QPixmapCache::insert( icn, pm);
+        }
 
         bfrp.fillRect(0,0,32,32,QColor("white"));
         bfrp.drawPixmap(4,4,pm);
@@ -540,8 +550,18 @@ void FWWindow::filePrint()
                         qDebug("Legend table: row=%d col=%d %s %s",
                                row,col,typeName.ascii(),objName.ascii());
 
-                    pm = QPixmap::fromMimeSource( Resources::global_res->getResourceStr(
-                                                      icon_path+string(typeName.latin1())+"/icon").c_str() );
+//                    pm = QPixmap::fromMimeSource( Resources::global_res->getResourceStr(
+//                        icon_path+string(typeName.latin1())+"/icon").c_str() );
+
+                    QString icn = Resources::global_res->getResourceStr(
+                        icon_path+string(typeName.latin1())+"/icon").c_str();
+                    QPixmap pm;
+                    if ( ! QPixmapCache::find( icn, pm) )
+                    {
+                        pm = QPixmap::fromMimeSource( icn );
+                        QPixmapCache::insert( icn, pm);
+                    }
+
 
                     bfrp.fillRect(0,0,32,32,QColor(white));
                     bfrp.drawPixmap(4,4,pm);
