@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FindObjectWidget.cpp,v 1.7 2006/08/04 22:15:26 vkurland Exp $
+  $Id: FindObjectWidget.cpp,v 1.8 2006/11/17 05:52:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -85,16 +85,18 @@ void FindObjectWidget::findObject(FWObject *o)
 
 void FindObjectWidget::enableAll()
 {
-    //useRegexp->setEnabled (true);
+    useRegexp->setEnabled (true);
     findAttr->setEnabled  (true);
     attribute->setEnabled (true);
 }
+
 void FindObjectWidget::disableAll()
 {
-    //useRegexp->setEnabled (false);
+    useRegexp->setEnabled (false);
     findAttr->setEnabled  (false);
     attribute->setEnabled (false);
 }
+
 void FindObjectWidget::objectInserted()
 {
     FWObject *o=findDropArea->getObject();
@@ -165,11 +167,11 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
     case 0:   // Name
     {
         QString name=QString::fromUtf8( obj->getName().c_str() );
-        /*
+        
         if (useRegexp->isChecked()) res= ( name.find( QRegExp(s) )!=-1 );
         else                        res= ( name == s );
-        */
-        res= ( name == s );
+        
+        //res= ( name == s );
         break;
         
     }
@@ -179,18 +181,17 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
         if (a!=NULL)
         {
             QString addr = a->getAddress().toString().c_str();
-            /*
+            
             if (useRegexp->isChecked()) res= ( addr.find( QRegExp(s) )!=-1 );
             else                        res= ( addr == s );
-            */
-            res= ( addr == s );
+            
+            //res= ( addr == s );
         }
         break;
     }
     case 2:   // port
         if (TCPService::cast(obj)!=NULL || UDPService::cast(obj)!=NULL)
         {
-            /*
             if (useRegexp->isChecked()) 
             {
                 QString port;
@@ -204,19 +205,19 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
                 res |= ( port.find( QRegExp(s) )!=-1 );
             } else
             {
-            */
-                int port = s.toInt();
-                res |= (port == obj->getInt("src_range_start"));
-                res |= (port == obj->getInt("src_range_end"));
-                res |= (port == obj->getInt("dst_range_start"));
-                res |= (port == obj->getInt("dst_range_end"));
-            //}
+                bool conversion_status = false;
+                int port = s.toInt(&conversion_status);
+                res |= (conversion_status && (port == obj->getInt("src_range_start")));
+                res |= (conversion_status && (port == obj->getInt("src_range_end")));
+                res |= (conversion_status && (port == obj->getInt("dst_range_start")));
+                res |= (conversion_status && (port == obj->getInt("dst_range_end")));
+            }
             break;
         }
+        break;
     case 3:   // protocol num.
         if (IPService::cast(obj)!=NULL)
         {
-            /*
             if (useRegexp->isChecked()) 
             {
                 QString proto;
@@ -224,16 +225,16 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
                 res |= ( proto.find( QRegExp(s) )!=-1 );
             } else
             {
-            */
-                int proto = s.toInt();
-                res |= (proto == obj->getInt("protocol_num"));
-            //}
+                bool conversion_status = false;
+                int proto = s.toInt(&conversion_status);
+                res |= (conversion_status && (proto == obj->getInt("protocol_num")));
+            }
             break;
         }
+        break;
     case 4:   // icmp type
         if (ICMPService::cast(obj)!=NULL)
         {
-            /*
             if (useRegexp->isChecked()) 
             {
                 QString icmptype;
@@ -241,12 +242,13 @@ bool FindObjectWidget::matchAttr(libfwbuilder::FWObject *obj)
                 res |= ( icmptype.find( QRegExp(s) )!=-1 );
             } else
             {
-            */
-                int icmptype = s.toInt();
-                res |= (icmptype == obj->getInt("type"));
-            //}
+                bool conversion_status = false;
+                int icmptype = s.toInt(&conversion_status);
+                res |= (conversion_status && (icmptype == obj->getInt("type")));
+            }
             break;
         }
+        break;
     }
 
     return res;
