@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.cpp,v 1.40 2006/09/11 00:41:09 vkurland Exp $
+  $Id: FirewallDialog.cpp,v 1.41 2006/12/01 05:57:39 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -268,6 +268,16 @@ void FirewallDialog::applyChanges()
         mw->scheduleRuleSetRedraw();
     }
 
+    if (oldplatform!=pl)
+    {
+        if (fwbdebug)
+            qDebug("FirewallDialog::applyChanges() platform has changed - clear option 'compiler'");
+        Firewall *s = Firewall::cast(obj);
+        assert(s!=NULL);
+        FWOptions  *opt =s->getOptionsObject();
+        opt->setStr("compiler","");
+    }
+
     init=true;
 
 /* move to another lib if we have to */
