@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.cpp,v 1.53 2006/09/15 05:48:21 vkurland Exp $
+  $Id: GroupObjectDialog.cpp,v 1.54 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,6 +57,7 @@
 #include <qpopupmenu.h>
 #include <qtooltip.h>
 #include <qscrollview.h>
+#include <qpixmapcache.h>
 
 #include <iostream>
 #include <algorithm>
@@ -357,9 +358,14 @@ void GroupObjectDialog::addIcon(FWObject *o,bool ref)
     QString icn_filename =
         Resources::global_res->getObjResourceStr(o, (ref)?"icon-ref":"icon").c_str();
 
-    ObjectIconViewItem *ivitm = new ObjectIconViewItem(iconView,
-                                                       obj_name,
-                                                       QPixmap::fromMimeSource( icn_filename ) );
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn_filename, pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn_filename );
+        QPixmapCache::insert( icn_filename, pm);
+    }
+
+    ObjectIconViewItem *ivitm = new ObjectIconViewItem(iconView,obj_name,pm );
     ivitm->setProperty("id",   o->getId().c_str()   );
     ivitm->setProperty("type", o->getTypeName().c_str() );
     ivitm->setFWObject( o );
@@ -371,7 +377,7 @@ void GroupObjectDialog::addIcon(FWObject *o,bool ref)
     ObjectListViewItem *tvitm=new ObjectListViewItem( listView );
     tvitm->setText( 0, obj_name );
     tvitm->setText( 1, FWObjectPropertiesFactory::getObjectProperties(o) );
-    tvitm->setPixmap( 0, QPixmap::fromMimeSource( icn_filename ) );
+    tvitm->setPixmap( 0, pm);
     tvitm->setDragEnabled(true);
 
     tvitm->setProperty("id",   o->getId().c_str()   );
