@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: HostDialog.cpp,v 1.16 2005/05/29 04:38:44 vkurland Exp $
+  $Id: HostDialog.cpp,v 1.19 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -69,7 +69,7 @@ void HostDialog::loadFWObject(FWObject *o)
 
     comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -92,7 +92,8 @@ void HostDialog::loadFWObject(FWObject *o)
     
 void HostDialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void HostDialog::validate(bool *res)
@@ -102,7 +103,7 @@ void HostDialog::validate(bool *res)
 
 void HostDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void HostDialog::libChanged()
@@ -140,7 +141,8 @@ void HostDialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void HostDialog::discardChanges()
