@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPServiceDialog.cpp,v 1.20 2004/06/17 06:37:00 vkurland Exp $
+  $Id: IPServiceDialog.cpp,v 1.23 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -69,7 +69,7 @@ void IPServiceDialog::loadFWObject(FWObject *o)
 
     comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -107,7 +107,8 @@ void IPServiceDialog::loadFWObject(FWObject *o)
     
 void IPServiceDialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void IPServiceDialog::validate(bool *res)
@@ -117,7 +118,7 @@ void IPServiceDialog::validate(bool *res)
 
 void IPServiceDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void IPServiceDialog::libChanged()
@@ -152,7 +153,8 @@ void IPServiceDialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void IPServiceDialog::discardChanges()
