@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibraryDialog.cpp,v 1.28 2006/05/13 06:53:05 vkurland Exp $
+  $Id: LibraryDialog.cpp,v 1.29 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -39,7 +39,7 @@
 #include <qcheckbox.h>
 #include <qtextedit.h>
 #include <qcolordialog.h>
-#include <qpixmap.h>
+#include <qpixmapcache.h>
 #include <qpushbutton.h>
 #include <qpainter.h>
 
