@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NetworkDialog.cpp,v 1.18 2004/06/17 06:37:00 vkurland Exp $
+  $Id: NetworkDialog.cpp,v 1.21 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -62,7 +62,7 @@ void NetworkDialog::loadFWObject(FWObject *o)
     netmask->setText( s->getNetmask().toString().c_str() );
     comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -85,7 +85,8 @@ void NetworkDialog::loadFWObject(FWObject *o)
     
 void NetworkDialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void NetworkDialog::validate(bool *res)
@@ -119,7 +120,7 @@ void NetworkDialog::validate(bool *res)
 
 void NetworkDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void NetworkDialog::libChanged()
@@ -160,8 +161,8 @@ void NetworkDialog::applyChanges()
         om->moveObject(libs->currentText(), obj);
 
     init=false;
-
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void NetworkDialog::discardChanges()
