@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjConflictResolutionDialog.cpp,v 1.17 2004/07/11 06:43:10 vkurland Exp $
+  $Id: ObjConflictResolutionDialog.cpp,v 1.18 2004/11/13 07:31:27 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -80,29 +80,52 @@ int ObjConflictResolutionDialog::run(    FWObject *o1,
 
     QString p1, p2;
 
-    if (o1->getParent()->getId()!=FWObjectDatabase::getDeletedObjectsId())
+    FWObject *delObjLib1 = o1->getRoot()->getById( DELETED_LIB );
+    FWObject *delObjLib2 = o2->getRoot()->getById( DELETED_LIB );
+
+    if (delObjLib1!=NULL && o1->isChildOf(delObjLib1))
+    {
+        /* This is the case when an object present in the file we are
+         * trying to load has been deleted in the tree. We can not
+         * just ignore deleted object in the tree and load a copy from
+         * the file because it will create a conflict (two objects
+         * with the same ID). I am not sur eI can delete object from
+         * here either. It is unclear how to solve this problem
+         * correctly. Defer to the user. */
+
+        p1=tr("Object <b>'%1'</b> has been deleted").arg(o1->getName().c_str());
+        rightBtnTxt = tr("Delete");
+        leftCB  = rightCB = leftBtn = false;
+    } else
         p1= FWObjectPropertiesFactory::getObjectPropertiesDetailed(o1,
                                                                    true,
                                                                    false,
                                                                    false);
-    else
-    {
-        p1=tr("Object <b>'%1'</b> has been deleted").arg(o1->getName().c_str());
-        rightBtnTxt = tr("Delete");
-        leftCB  = rightCB = leftBtn = false;
-    }
 
-    if (o2->getParent()->getId()!=FWObjectDatabase::getDeletedObjectsId())
+    if (delObjLib2!=NULL && o2->isChildOf(delObjLib2))
+    {
+        /* This is the case where object o2 has been deleted in the
+         * file we are trying to load but is present in the tree.  One
+         * situation when this occurs is when we preloaded bunch of
+         * libraries and this object is in one of them but has been
+         * deleted in the file. We should ignore deleted objects in
+         * the file and use copy present in the tree.
+         */
+
+        cerr << "Deleted object found: o2 "
+             << o2->getId() << " " << o2->getName() << endl;
+
+        return QDialog::Rejected;
+
+        p2=tr("Object <b>'%1'</b> has been deleted").arg(o2->getName().c_str());
+        leftBtnTxt = tr("Delete");
+        leftCB  = rightCB = rightBtn = false;
+    } else
         p2= FWObjectPropertiesFactory::getObjectPropertiesDetailed(o2,
                                                                    true,
                                                                    false,
                                                                    false);
-    else
-    {
-        p2=tr("Object <b>'%1'</b> has been deleted").arg(o2->getName().c_str());
-        leftBtnTxt = tr("Delete");
-        leftCB  = rightCB = rightBtn = false;
-    }
+    
 
     useCurrentObj->setText(leftBtnTxt);
     useNewObj->setText(rightBtnTxt);
