@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.cpp,v 1.151 2006/09/15 05:48:21 vkurland Exp $
+  $Id: ObjectManipulator.cpp,v 1.159 2006/10/22 18:20:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -47,7 +47,7 @@
 #include <qobjectlist.h>
 #include <qlistview.h>
 #include <qimage.h>
-#include <qpixmap.h>
+#include <qpixmapcache.h>
 #include <qheader.h>
 #include <qwidgetstack.h>
 #include <qpushbutton.h>
@@ -148,7 +148,6 @@ ObjectManipulator::ObjectManipulator( QWidget *parent ) :
     currentObj   = NULL;
     active       = false;
     currentTreeView=NULL;
-    searchId =0;
 
 //    setFocusPolicy( QWidget::StrongFocus  );
 
@@ -260,7 +259,19 @@ ObjectTreeViewItem* ObjectManipulator::insertObject( ObjectTreeViewItem *itm,
     nitm=new ObjectTreeViewItem( itm );
     nitm->setLib("");
     nitm->setText( 0, getTreeLabel(obj) );
-    nitm->setPixmap( 0, QPixmap::fromMimeSource( icn_filename ) );
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn_filename, pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn_filename );
+        QPixmapCache::insert( icn_filename, pm);
+        if (fwbdebug)
+            qDebug("Created pixmap from %s  w=%d h=%d depth=%d",
+                   icn_filename.ascii(),
+                   pm.width(),
+                   pm.height(),
+                   pm.depth());
+    }
+    nitm->setPixmap( 0, pm );
     nitm->setDragEnabled(true);
 
     nitm->setProperty("id",   obj->getId().c_str()   );
@@ -644,8 +655,13 @@ void ObjectManipulator::addLib( FWObject *lib,QListView* otv)
         if ( libs->text(idx) > newlibname ) break;
 
     string icn=Resources::global_res->getObjResourceStr(lib,"icon-tree").c_str();
-    libs->insertItem( QPixmap::fromMimeSource( icn.c_str() ),
-                      newlibname, idx);
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn.c_str(), pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn.c_str() );
+        QPixmapCache::insert( icn.c_str(), pm);
+    }
+    libs->insertItem( pm, newlibname, idx);
 //    idx=libs->count()-1;
 
     libs->setCurrentItem(idx);
@@ -712,11 +728,24 @@ void ObjectManipulator::addTreePage( FWObject *lib)
 
     itm1->setText( 0 , getTreeLabel( lib ) );
     if (lib->isReadOnly())
-        itm1->setPixmap(0, QPixmap::fromMimeSource( "lock.png" ) );
-    else
+    {
+        QPixmap pm;
+        if ( ! QPixmapCache::find( "lock.png", pm) )
+        {
+            pm = QPixmap::fromMimeSource( "lock.png" );
+            QPixmapCache::insert( "lock.png", pm);
+        }
+        itm1->setPixmap(0, pm );
+    } else
     {   
         string icn=Resources::global_res->getObjResourceStr(lib,"icon-tree").c_str();
-        itm1->setPixmap( 0, QPixmap::fromMimeSource( icn.c_str() ));
+        QPixmap pm;
+        if ( ! QPixmapCache::find( icn.c_str(), pm) )
+        {
+            pm = QPixmap::fromMimeSource( icn.c_str() );
+            QPixmapCache::insert( icn.c_str(), pm);
+        }
+        itm1->setPixmap( 0, pm);
     }
 
     itm1->setProperty("id",   lib->getId().c_str()   );
@@ -1202,7 +1231,7 @@ void ObjectManipulator::extractFirewallsFromGroup(ObjectGroup *gr,set<Firewall*>
 {
    Firewall *f;
    set<FWObject*> oset;
-   findObjectsInGroup(gr,oset);
+   mw->db()->findObjectsInGroup(gr,oset);
    
    set<FWObject*>::iterator i;
    for(i=oset.begin();i!=oset.end();++i)   
@@ -1617,6 +1646,7 @@ void ObjectManipulator::lockObject()
     getCurrentObjectTree()->setLockFlags();
     getCurrentObjectTree()->updateTreeItems();
 }
+
 void ObjectManipulator::unlockObject()
 {
     if (fwbdebug)
@@ -1636,6 +1666,7 @@ void ObjectManipulator::unlockObject()
     getCurrentObjectTree()->setLockFlags();
     getCurrentObjectTree()->updateTreeItems();
 }
+
 void ObjectManipulator::deleteObj()
 {
     if (fwbdebug)
@@ -1648,17 +1679,19 @@ void ObjectManipulator::deleteObj()
     bool emptyingTrash      = false;
     bool emptyingTrashInLib = false;
 
-    FWObject *delObjLib = mw->db()->findInIndex(
-        FWObjectDatabase::getDeletedObjectsId());
+    FWObject *delObjLib = mw->db()->findInIndex(FWObjectDatabase::getDeletedObjectsId());
     if (fwbdebug)
         qDebug("ObjectManipulator::deleteObj  delObjLib=%p",delObjLib);
 
     vector<FWObject*> so = getCurrentObjectTree()->getSimplifiedSelection();
 
-    for (vector<FWObject*>::iterator i=so.begin();  i!=so.end(); ++i)
+    if (delObjLib!=NULL)
     {
-        obj= *i;
-        emptyingTrash |= obj->isChildOf(delObjLib);
+        for (vector<FWObject*>::iterator i=so.begin();  i!=so.end(); ++i)
+        {
+            obj= *i;
+            emptyingTrash |= obj->isChildOf(delObjLib);
+        }
     }
 
     emptyingTrashInLib = emptyingTrash && mw->editingLibrary();
@@ -1681,7 +1714,7 @@ void ObjectManipulator::deleteObj()
     if (emptyingTrashInLib)
     {
         msg = tr(
-    "Emptying of the 'Deleted Objects' in a library file is not recommended.\n"
+    "Emptying the 'Deleted Objects' in a library file is not recommended.\n"
     "When you remove deleted objects from a library file, Firewall Builder\n"
     "loses ability to track them. If a group or a policy rule in some\n"
     "data file still uses removed object from this library, you may encounter\n"
@@ -1694,6 +1727,14 @@ void ObjectManipulator::deleteObj()
                 0, 1 )!=0) return;
     } else
     {
+
+        if (fwbdebug)
+            qDebug("ObjectManipulator::deleteObj emptyingTrash=%d so.size=%d  so.front()->type=%s",
+                   emptyingTrash,
+                   so.size(),
+                   so.front()->getTypeName().c_str() );
+        
+
         if (!emptyingTrash && (so.size()>1 || !Library::isA(so.front())))
         {
             /*
@@ -1864,11 +1905,14 @@ void ObjectManipulator::delObj(FWObject *obj,bool openobj)
             {
                 std::list<Firewall*> fwlist;
                 findAllFirewalls(fwlist);
-                FWObject *first_fw = fwlist.front();
-                if (first_fw!=NULL)
+                if (fwlist.size()>0)
                 {
-                    mw->showFirewall( first_fw );
-                    openObject( first_fw );
+                    FWObject *first_fw = fwlist.front();
+                    if (first_fw!=NULL)
+                    {
+                        mw->showFirewall( first_fw );
+                        openObject( first_fw );
+                    }
                 }
                 //QTimer::singleShot( 0, mw, SLOT(reopenFirewall()) );
             } else {
@@ -2682,75 +2726,6 @@ bool ObjectManipulator::isSelected()
     return active;
 }
 
-void ObjectManipulator::findWhereUsed(FWObject *o,FWObject *p,set<FWObject *> &resset)
-{
-    if (fwbdebug) qDebug("----------------------------------------");
-    if (fwbdebug) qDebug("ObjectManipulator::findWhereUsed");
-    searchId++;
-    _findWhereUsed(o,p,resset);
-    if (fwbdebug)
-    {
-        qDebug(QString("Found following objects in ")+p->getName().c_str() );
-        for (set<FWObject *>::iterator i=resset.begin(); i!=resset.end();++i)
-            qDebug(QString(">")+(*i)->getTypeName().c_str()+" ("+(*i)->getName().c_str()+")");
-    }
-    
-}
-
-bool isInIgnoreList(FWObject *o)
-{
-    return FWOptions::cast(o);
-}
-
-bool ObjectManipulator::_findWhereUsed(FWObject *o,FWObject *p,set<FWObject *> &resset)
-{
-#if 0
-    if (fwbdebug)
-    {
-        qDebug("ObjectManipulator::_findWhereUsed");
-        qDebug(QString("Object:")+o->getName().c_str());
-        qDebug(QString("Parent:")+p->getTypeName().c_str()+" ("+p->getName().c_str()+")" );
-    }
-#endif
-
-    bool res=false;
-        
-    if ( isInIgnoreList(p) || p->size()==0) return res;
-    
-    if (p->getInt(".searchId")==searchId)
-    {
-        res=p->getBool(".searchResult");
-        return res;
-    }
-
-// set flags to break indefinite recursion in case we encounter circular groups
-    p->setInt(".searchId",searchId);
-    p->setBool(".searchResult",res);   // res==false at this time
-   
-    FWObject::iterator i1=p->begin();
-    for (;i1!=p->end(); ++i1)
-    {
-        if ((*i1)->getId()==FWObjectDatabase::getDeletedObjectsId()) continue;
-
-        FWReference  *ref=FWReference::cast(*i1);
-        if (ref!=NULL)
-        {  // child is a reference
-            FWObject *g=ref->getPointer();
-            if (o==g) res= true;
-            else      res |= _findWhereUsed(o,g,resset);
-        }
-        else    // child is a regular object, not a reference
-        {
-            if (o==(*i1))  res=true;
-            else           res |= _findWhereUsed(o,*i1,resset);
-        }
-    }
-
-    p->setBool(".searchResult",res);
-    if (res) resset.insert(p);
-    return res;
-}
-
 list<Firewall *> ObjectManipulator::findFirewallsForObject(FWObject *o)
 {
     if (fwbdebug)
@@ -2763,7 +2738,7 @@ list<Firewall *> ObjectManipulator::findFirewallsForObject(FWObject *o)
     FWObject *f=o;
     while (f!=NULL && !Firewall::isA(f)) f=f->getParent();
     if (f) fws.push_back(Firewall::cast(f));
-    findWhereUsed(o,mw->db(),resset);
+    mw->db()->findWhereUsed(o,mw->db(),resset);
     
     set<FWObject *>::iterator i=resset.begin();
     for ( ;i!=resset.end();++i)
@@ -2898,50 +2873,11 @@ void ObjectManipulator::findAllFirewalls (list<Firewall *> &fws)
         fws.push_back( Firewall::cast(*m) );
 }
 
-void ObjectManipulator::findObjectsInGroup(Group *g,set<FWObject *> &res)
-{
-    if (fwbdebug) qDebug("ObjectManipulator::findObjectsInGroup");
-    searchId++;
-    _findObjectsInGroup(g,res);
-}
-
-void ObjectManipulator::_findObjectsInGroup(Group *g,set<FWObject *> &res)
-{
-    if (fwbdebug) qDebug("ObjectManipulator::_findObjectsInGroup");
-    if (g->size()==0 || g->getInt(".searchId")==searchId) return;
-    
-    g->setInt(".searchId",searchId);
-    FWObjectReference *ref;
-    Group *sg;
-    FWObject *obj;
-    FWObject::iterator i=g->begin();
-    for(;i!=g->end();++i)
-    {
-        
-       ref=FWObjectReference::cast(*i);
-       if (ref==NULL) 
-       {
-           res.insert(*i);
-           continue;
-       }
-       
-       obj=ref->getPointer();
-       sg=Group::cast(obj);
-       
-       if (sg==NULL)
-       {
-           res.insert(obj);
-           continue;
-       }
-       
-       _findObjectsInGroup(sg,res);
-    }    
-}
-
 FWObject* ObjectManipulator::getSelectedObject()
 {
     return currentObj;
 }
+
 void ObjectManipulator::findWhereUsedSlot()
 {
     if (getCurrentObjectTree()->getNumSelected()==0) return;
