@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.h,v 1.56 2006/08/18 04:10:33 vkurland Exp $
+  $Id: ObjectManipulator.h,v 1.57 2006/10/15 21:43:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -80,7 +80,6 @@ class ObjectManipulator : public ObjectManipulator_q {
     std::vector<QListView*>                       idxToTrees;
     
     std::stack<HistoryItem>                       history;
-    int searchId;
     int cacheHits;
 
     libfwbuilder::FWObject                        *currentObj;
@@ -122,12 +121,6 @@ class ObjectManipulator : public ObjectManipulator_q {
     void extractFirewallsFromGroup(
             libfwbuilder::ObjectGroup *gr,
             std::set<libfwbuilder::Firewall*> &fo);
-    void findObjectsInGroup(
-            libfwbuilder::Group *g,
-            std::set<libfwbuilder::FWObject *> &res);
-    void _findObjectsInGroup(
-            libfwbuilder::Group *g,
-            std::set<libfwbuilder::FWObject *> &res);
 
 public slots:
      virtual void libChanged(int l);
@@ -321,16 +314,6 @@ public slots:
     void updateLastInstalledTimestamp(libfwbuilder::FWObject *o);
     void updateLastCompiledTimestamp(libfwbuilder::FWObject *o);
     
-    void findWhereUsed(
-            libfwbuilder::FWObject *o,
-            libfwbuilder::FWObject *p,
-            std::set<libfwbuilder::FWObject *> &resset);
-
-    bool _findWhereUsed(
-            libfwbuilder::FWObject *o,
-            libfwbuilder::FWObject *p,
-            std::set<libfwbuilder::FWObject *> &resset);
-    
     std::list<libfwbuilder::Firewall * > findFirewallsForObject(libfwbuilder::FWObject *o);
     void findAllFirewalls (std::list<libfwbuilder::Firewall *> &fws);
 
