@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.cpp,v 1.35 2006/09/15 05:48:21 vkurland Exp $
+  $Id: ObjectTreeView.cpp,v 1.37 2006/10/22 18:20:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -45,6 +45,7 @@
 #include <qlistview.h>
 #include <qheader.h>
 #include <qpainter.h>
+#include <qpixmapcache.h>
 
 #include <iostream>
 #include <algorithm>
@@ -202,11 +203,14 @@ void ObjectTreeView::updateTreeItems()
     QListViewItem *itm;
     ObjectTreeViewItem *otvi;
     FWObject *obj;
-    QPixmap pix(16,16);
-    string icn;
-    QImage img;
-    QImage img_lock=QImage::fromMimeSource( "lock.png" );
-    //img_lock=img_lock.scale(10,10);
+    QString icn;
+
+    QPixmap pm_lock;
+    if ( ! QPixmapCache::find( "lock.png", pm_lock) )
+    {
+        pm_lock = QPixmap::fromMimeSource( "lock.png" );
+        QPixmapCache::insert( "lock.png", pm_lock);
+    }
     
     while ( it.current() ) 
     {
@@ -215,27 +219,19 @@ void ObjectTreeView::updateTreeItems()
         obj=otvi->getFWObject();
         
         if (FWBTree::isSystem(obj))
-        {
             icn="folder1.png";
-        }
         else
-        {
             icn=Resources::global_res->getObjResourceStr(obj, "icon-tree").c_str();
-        }
-        img=QImage::fromMimeSource( icn.c_str() );
         
-        if (obj->getBool("ro"))
+        QPixmap pm_obj;
+        if ( ! QPixmapCache::find( icn, pm_obj) )
         {
-            //QPainter painter(&img);
-            //painter.drawImage(6,6,img_lock);
+            pm_obj = QPixmap::fromMimeSource( icn );
+            QPixmapCache::insert( icn, pm_obj);
+        }
 
-            img=img_lock;
-        }
-        else
-        {
-        }
-        
-        itm->setPixmap(0, img );
+        if (obj->getBool("ro"))  itm->setPixmap(0, pm_lock );
+        else                     itm->setPixmap(0, pm_obj );
         
         Firewall *fw=Firewall::cast(obj);
         if (fw!=NULL)
@@ -274,7 +270,7 @@ QDragObject* ObjectTreeView::dragObject()
 
     if (FWBTree::isSystem(obj)) return NULL;
 */
-    QString icn_filename =
+    QString icn =
         Resources::global_res->getObjResourceStr(obj, "icon-ref").c_str();
 
     vector<FWObject*> so = getSimplifiedSelection();
@@ -284,7 +280,14 @@ QDragObject* ObjectTreeView::dragObject()
         dragobj.push_back( *v );
 
     FWObjectDrag    *drag = new FWObjectDrag(dragobj, this);
-    QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+    //QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn, pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn );
+        QPixmapCache::insert( icn, pm);
+    }
 
     if (dragobj.size()>1)
     {
