@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.cpp,v 1.59 2006/07/19 06:21:08 vkurland Exp $
+  $Id: RCS.cpp,v 1.62 2006/10/21 06:53:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -209,7 +209,7 @@ RCSEnvFix::RCSEnvFix()
  * everything works. When the program is started with some other
  * directory as current dir, RCS tools fail without any error message.
  */
-    env.push_back( QString("PATH=")+appRootDir+";"+getenv("PATH") );
+    env.push_back( QString("PATH=%1;%2").arg(appRootDir.c_str()).arg(getenv("PATH")) );
 #endif
 
 /* also need to set env variable USER for rcs tools, but if the user name
@@ -239,11 +239,21 @@ RCS::RCS(const QString &file)
     if (rcs_file_name=="")
     {
 #ifdef _WIN32
-        rcs_file_name     = appRootDir+FS_SEPARATOR+RCS_FILE_NAME      ;
-        rlog_file_name    = appRootDir+FS_SEPARATOR+RLOG_FILE_NAME     ;
-        rcsdiff_file_name = appRootDir+FS_SEPARATOR+RCSDIFF_FILE_NAME  ;
-        ci_file_name      = appRootDir+FS_SEPARATOR+CI_FILE_NAME       ;
-        co_file_name      = appRootDir+FS_SEPARATOR+CO_FILE_NAME       ;
+        string ts;
+        ts     = appRootDir+FS_SEPARATOR+RCS_FILE_NAME      ;
+        rcs_file_name     = ts.c_str();
+
+        ts    = appRootDir+FS_SEPARATOR+RLOG_FILE_NAME     ;
+        rlog_file_name    = ts.c_str();
+
+        ts = appRootDir+FS_SEPARATOR+RCSDIFF_FILE_NAME  ;
+        rcsdiff_file_name = ts.c_str();
+
+        ts      = appRootDir+FS_SEPARATOR+CI_FILE_NAME       ;
+        ci_file_name      = ts.c_str();
+
+        ts      = appRootDir+FS_SEPARATOR+CO_FILE_NAME       ;
+        co_file_name      = ts.c_str();
 #else
         rcs_file_name     = RCS_FILE_NAME      ;
         rlog_file_name    = RLOG_FILE_NAME     ;
