@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHPIX.cpp,v 1.14 2006/05/08 01:26:18 vkurland Exp $
+  $Id: SSHPIX.cpp,v 1.17 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -47,11 +47,12 @@ extern int errno;
 
 using namespace std;
 
-SSHPIX::SSHPIX(const QString &_h,
+SSHPIX::SSHPIX(QWidget *_par,
+               const QString &_h,
                const QStringList &args,
                const QString &_p,
                const QString &_ep,
-               const std::list<std::string> &_in) : SSHSession(_h,args,_p,_ep,_in)
+               const std::list<std::string> &_in) : SSHSession(_par,_h,args,_p,_ep,_in)
 {
     normal_prompt="> $";
     fwb_prompt="--**--**--";
@@ -120,10 +121,14 @@ void SSHPIX::stateMachine()
     {
         if ( stdoutBuffer.findRev(*i,-1)!=-1 )
         {
+            if (fwbdebug)
+                qDebug(QString("Got known error message: %1").arg(stdoutBuffer));
+
             emit printStdout_sign( tr("\n*** Fatal error :") );
             emit printStdout_sign( stdoutBuffer+"\n" );
             stdoutBuffer="";
-            terminate();
+//            terminate();
+            sessionComplete(true);   // finish with error status
             return;
         }
     }
@@ -147,8 +152,8 @@ void SSHPIX::stateMachine()
         {
             state=LOGGEDIN;
             emit printStdout_sign( "\n");
-            emit printStdout_sign( tr("Logged in\n") );
-            emit printStdout_sign( tr("Switching to enable mode...\n"));
+            emit printStdout_sign( tr("Logged in") + "\n" );
+            emit printStdout_sign( tr("Switching to enable mode...") + "\n");
             stdoutBuffer="";
             proc->writeToStdin( "enable\n" );
         }
@@ -159,6 +164,7 @@ void SSHPIX::stateMachine()
             stdoutBuffer.find(newKeyPlink)!=-1)
         {
 /* new key */
+            if (fwbdebug) qDebug("New host key message detected");
 
             n1=stdoutBuffer.find(fingerprintPrompt) + strlen(fingerprintPrompt);
             n2=stdoutBuffer.find(QRegExp("[^ 0-9a-f:]"), n1+4);
@@ -166,10 +172,17 @@ void SSHPIX::stateMachine()
 
             QString msg=newKeyMsg.arg(host).arg(fingerprint).arg(host);
 
-            int res =QMessageBox::warning( NULL, tr("New RSA key"), msg,
+            stopHeartBeat();
+
+            int res =QMessageBox::warning( parent, tr("New RSA key"), msg,
                                            tr("Yes"), tr("No"), 0,
                                            0, -1 );
 
+            if (fwbdebug)
+                qDebug("User said: res=%d", res);
+
+            startHeartBeat();
+
             stdoutBuffer="";
             if (res==0)
             {
@@ -177,8 +190,10 @@ void SSHPIX::stateMachine()
                 break;
             } else
             {
-                state=EXIT;
-                goto entry;
+                sessionComplete(true);   // finish with error status
+                return;
+//                state=EXIT;
+//                goto entry;
             }
         }
     }
@@ -188,7 +203,7 @@ void SSHPIX::stateMachine()
         if ( cmpPrompt(stdoutBuffer,QRegExp(epwd_prompt)) )
         {
             stdoutBuffer="";
-            proc->writeToStdin( epwd );
+            if (!epwd.isEmpty()) proc->writeToStdin( epwd );
             proc->writeToStdin( "\n" );
             state=WAITING_FOR_ENABLE;
         }
@@ -198,7 +213,7 @@ void SSHPIX::stateMachine()
         if ( cmpPrompt(stdoutBuffer,QRegExp(epwd_prompt)) )
         {
             stdoutBuffer="";
-            proc->writeToStdin( epwd );
+            if (!epwd.isEmpty()) proc->writeToStdin( epwd );
             proc->writeToStdin( "\n" );
             state=WAITING_FOR_ENABLE;
             break;
@@ -253,7 +268,7 @@ void SSHPIX::stateMachine()
             if ( ! *config_file)
             {
                 emit printStdout_sign(
-                    QObject::tr("Can not open file %1").arg(ff)
+                    QObject::tr("Can not open file %1").arg(ff) + "\n"
                 );
                 state=FINISH;
                 break;
@@ -355,7 +370,7 @@ void SSHPIX::stateMachine()
 //                goto entry;
 
                 state=EXIT_FROM_CONFIG;
-                emit printStdout_sign( tr("End\n") );
+                emit printStdout_sign( tr("End") + "\n" );
                 proc->writeToStdin( "exit\n" );
             }
         }
@@ -403,7 +418,7 @@ void SSHPIX::stateMachine()
  */
             if (!dry_run && !testRun && ncmd!=0)
             {
-                emit printStdout_sign( tr("Save configuration\n") );
+                emit printStdout_sign( tr("Save configuration") + "\n" );
                 state=SAVE_CONFIG;
                 proc->writeToStdin( "wr mem\n");
             } else
@@ -419,12 +434,12 @@ void SSHPIX::stateMachine()
         {
             if (saveStandby && ncmd!=0)
             {
-                emit printStdout_sign( tr("Save configuration to standby unit\n") );
+                emit printStdout_sign( tr("Save configuration to standby unit") + "\n" );
                 state=SAVE_STANDBY;
                 proc->writeToStdin( "wr standby\n");
             } else
             {
-                emit printStdout_sign( tr("Exiting\n") );
+                emit printStdout_sign( tr("Exiting") + "\n" );
                 state=EXIT;
                 proc->writeToStdin( "exit\n");
             }
@@ -434,7 +449,7 @@ void SSHPIX::stateMachine()
     case SAVE_STANDBY:
         if ( cmpPrompt(stdoutBuffer,QRegExp(enable_prompt)) )
         {
-            emit printStdout_sign( tr("Exiting\n") );
+            emit printStdout_sign( tr("Exiting") + "\n" );
             state=EXIT;
             proc->writeToStdin( "exit\n");
         }
@@ -609,7 +624,7 @@ void SSHPIX::clearObjectGroups()
     }
 
     state=EXIT_FROM_CONFIG;
-    emit printStdout_sign( tr("*** End ") );
+    emit printStdout_sign( tr("*** End ") + "\n" );
     proc->writeToStdin( "exit\n" );
 }
 
@@ -666,12 +681,12 @@ void SSHPIX::PIXincrementalInstall()
             {
             case EAGAIN: 
             case ENOMEM:
-                emit printStdout_sign(tr("Not enough memory."));
+                emit printStdout_sign(tr("Not enough memory.") + "\n");
                 break;
             case EMFILE:
             case ENFILE:
                 emit printStdout_sign(
-                    tr("Too many opened file descriptors in the system."));
+                    tr("Too many opened file descriptors in the system.") + "\n");
                 break;
 
             }
@@ -711,7 +726,7 @@ void SSHPIX::PIXincrementalInstall()
         state=PUSHING_CONFIG;
         emit updateProgressBar_sign(nLines,true);
         if (!dry_run)
-            emit printStdout_sign(tr("Pushing firewall configuration\n"));
+            emit printStdout_sign(tr("Pushing firewall configuration") + "\n");
     }
     proc->writeToStdin( "\n" );
 }
