@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.h,v 1.14 2006/05/08 01:26:18 vkurland Exp $
+  $Id: SSHSession.h,v 1.16 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,6 +42,7 @@
 
 class QTimer;
 class instConf;
+class QWidget;
 
 class SSHSession : public QObject {
 
@@ -49,6 +50,7 @@ class SSHSession : public QObject {
 
  protected:
 
+    QWidget    *parent;
     QProcess   *proc;
     int         retcode;
     QTimer     *heartBeatTimer;
@@ -126,7 +128,9 @@ class SSHSession : public QObject {
     QStringList errorsInit;
     QStringList errorsLoggedin;
     QStringList errorsEnabledState;
-    
+
+    QString     pendingLogLine;
+
     QString pwd;
     QString epwd;
     QString host;
@@ -141,10 +145,14 @@ class SSHSession : public QObject {
     
     bool cmpPrompt(const QString &str,const QString &prompt);
     bool cmpPrompt(const QString &str,const QRegExp &prompt);
-    
+
+    void startHeartBeat();
+    void stopHeartBeat();
+
 public:
     
-    SSHSession(const QString &host,
+    SSHSession(QWidget *parent,
+               const QString &host,
 	       const QStringList &args,
 	       const QString &pwd,
 	       const QString &epwd,
@@ -176,7 +184,9 @@ public:
     void setDiffPgm(const QString &v) { diff_pgm=v; }
     void setDiffFile(const QString &v) { diff_file=v; }
     bool getErrorStatus() { return error; }
-    
+
+    void sessionComplete(bool err);
+ 
 public slots:
      void readFromStdout();
      void readFromStderr();
@@ -190,6 +200,7 @@ public slots:
 
  void printStdout_sign(const QString &line);
  void sessionFinished_sign();
+ void sessionFatalError_sign();
  void updateProgressBar_sign(int n,bool setsize);
 
 
