@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.cpp,v 1.15 2006/05/08 01:26:18 vkurland Exp $
+  $Id: SSHUnx.cpp,v 1.18 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,11 +42,12 @@
 
 using namespace std;
 
-SSHUnx::SSHUnx(const QString &_h,
+SSHUnx::SSHUnx(QWidget *_par,
+               const QString &_h,
                const QStringList &args,
                const QString &_p,
                const QString &_ep,
-               const list<string> &_in) : SSHSession(_h,args,_p,_ep,_in)
+               const list<string> &_in) : SSHSession(_par,_h,args,_p,_ep,_in)
 {
     normal_prompt="> ";
     enable_prompt="# ";
@@ -91,7 +92,8 @@ void SSHUnx::stateMachine()
             emit printStdout_sign( tr("\n*** Fatal error :") );
             emit printStdout_sign( stdoutBuffer+"\n" );
             stdoutBuffer="";
-            terminate();
+//            terminate();
+            sessionComplete(true);   // finish with error status
             return;
         }
     }
@@ -120,7 +122,7 @@ void SSHUnx::stateMachine()
             cmpPrompt(stdoutBuffer,fwb_prompt))
         {
             state=PUSHING_CONFIG;
-            if (!quiet) emit printStdout_sign( tr("Logged in\n") );
+            if (!quiet) emit printStdout_sign( tr("Logged in") + "\n" );
             if (fwbdebug)
                 qDebug("SSHUnx::stateMachine logged in");
 //            proc->writeToStdin( "\n" );
@@ -142,11 +144,17 @@ void SSHUnx::stateMachine()
 
             QString msg=newKeyMsg.arg(host).arg(fingerprint).arg(host);
 
-/* TODO: need to use a reference to the main window or installer dialog  */
-            int res =QMessageBox::warning( NULL, tr("New RSA key"), msg,
+            stopHeartBeat();
+
+            int res =QMessageBox::warning( parent, tr("New RSA key"), msg,
                                            tr("Yes"), tr("No"), 0,
                                            0, -1 );
 
+            if (fwbdebug)
+                qDebug("User said: res=%d", res);
+
+            startHeartBeat();
+
             stdoutBuffer="";
             if (res==0)
             {
@@ -157,8 +165,10 @@ void SSHUnx::stateMachine()
                 break;
             } else
             {
-                state=EXIT;
-                goto entry;
+                sessionComplete(true);   // finish with error status
+                return;
+//                state=EXIT;
+//                goto entry;
             }
         }
     }
@@ -213,7 +223,8 @@ void SSHUnx::stateMachine()
             emit printStdout_sign( tr("Error in SSH") );
             emit printStdout_sign( "\n");
 
-            terminate();
+//            terminate();
+            sessionComplete(true);   // finish with error status
             proc=NULL;
         }
 
