@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TimeDialog.cpp,v 1.12 2004/12/05 21:52:31 vkurland Exp $
+  $Id: TimeDialog.cpp,v 1.15 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -111,7 +111,7 @@ void TimeDialog::loadFWObject(FWObject *o)
     endDOW->setValue( obj->getInt("to_weekday") );
 
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
 
     obj_name->setEnabled(!o->isReadOnly());
@@ -147,7 +147,8 @@ void TimeDialog::loadFWObject(FWObject *o)
     
 void TimeDialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void TimeDialog::validate(bool *res)
@@ -157,7 +158,7 @@ void TimeDialog::validate(bool *res)
 
 void TimeDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void TimeDialog::libChanged()
@@ -197,7 +198,8 @@ void TimeDialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void TimeDialog::discardChanges()
