@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: UDPServiceDialog.cpp,v 1.21 2004/06/17 06:37:01 vkurland Exp $
+  $Id: UDPServiceDialog.cpp,v 1.24 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -63,7 +63,7 @@ void UDPServiceDialog::loadFWObject(FWObject *o)
 
     comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -92,7 +92,8 @@ void UDPServiceDialog::loadFWObject(FWObject *o)
     
 void UDPServiceDialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void UDPServiceDialog::validate(bool *res)
@@ -102,7 +103,7 @@ void UDPServiceDialog::validate(bool *res)
 
 void UDPServiceDialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
 }
 
 void UDPServiceDialog::libChanged()
@@ -137,7 +138,8 @@ void UDPServiceDialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void UDPServiceDialog::discardChanges()
