@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.94 2006/09/17 05:15:50 vkurland Exp $
+  $Id: instDialog.cpp,v 1.95 2006/10/21 06:19:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1508,15 +1508,16 @@ Can't compile firewall policy."),
  */
 #if defined(Q_OS_WIN32) ||  defined(Q_OS_MACX)
 
-    if ( ! QFile::exists( compiler ) )
+    if ( ! QFile::exists( compiler.c_str() ) )
     {
-        QString cmppath = st->getStr( QString("Compilers/")+compiler );
+        string ts = string("Compilers/")+compiler;
+        QString cmppath = st->getStr( ts.c_str() );
         if (!cmppath.isEmpty()) compiler=cmppath.latin1();
         else
         {
             /* try to find compiler in appRootDir. */
-
-            if ( QFile::exists( appRootDir + FS_SEPARATOR + compiler ) )
+            string ts =  appRootDir + FS_SEPARATOR + compiler;
+            if ( QFile::exists( ts.c_str() ) )
                 compiler = appRootDir + FS_SEPARATOR + compiler;
         }
     }
