@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.h,v 1.29 2006/07/23 23:27:22 vkurland Exp $
+  $Id: instDialog.h,v 1.32 2006/09/16 07:00:53 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -46,7 +46,7 @@
 
 class QEventLoop;
 class SSHSession;
-class QTextBrowser;
+class QTextEdit;
 class QListViewItem;
 class QCheckListItem;
 class QButton;
@@ -74,7 +74,7 @@ class instDialog : public instDialog_q {
 
     bool        ready;
     bool        activationCommandDone;
-    instConf   cnf;
+    instConf    cnf;
 
     QString     ssh;
     
@@ -90,8 +90,15 @@ class instDialog : public instDialog_q {
     QString getActivationCmd();
     //libfwbuilder::Firewall * firewall;
     t_fwSet reqFirewalls;
+
+
+    // session is used when e run built-in installer
     SSHSession  *session;
-    
+
+    // proc is used to launch external oprocess, such as compiler or
+    // user-defined installer script
+    QProcess       proc;
+
     std::map<libfwbuilder::Firewall *, t_procMess>    processedFirewalls;
 
     t_fwList    firewalls;
@@ -105,7 +112,7 @@ class instDialog : public instDialog_q {
     
     QStringList args;
         
-    QTextBrowser *currentLog;
+    QTextEdit    *currentLog;
     QButton      *currentSaveButton;
     QButton      *currentStopButton;
     QProgressBar *currentProgressBar;
@@ -116,8 +123,8 @@ class instDialog : public instDialog_q {
     
     BatchOperation operation;
     instOptionsDialog_q *dlg;
-    QProcess proc;
-    
+    QString        pendingLogLine;
+
     int progress;
     int totalRules;
     int processedRules;
@@ -133,7 +140,7 @@ class instDialog : public instDialog_q {
     void fillCompileOpList();
     void fillLastList();
     bool doInstallPage();
-    void doOptionsPage();    
+    void resetInstallSSHSession();    
     bool testFirewall(libfwbuilder::Firewall*);
     void finishInstall(bool success=true);
     void fillInstallOpList();
@@ -164,7 +171,7 @@ class instDialog : public instDialog_q {
     bool isTableHasChecked();
     void clearReqFirewalls();
     void addReqFirewall(libfwbuilder::Firewall *f);
-    
+    void addToLog(const QString &buf); 
     
  protected:
 
@@ -177,6 +184,8 @@ class instDialog : public instDialog_q {
     virtual void findFirewalls();
  protected slots:
      void processExited();
+     void installerFinished();
+     void installerError();
      void selected(const QString &title);
      void reject();
      void testRunRequested();
