@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iptAdvancedDialog.cpp,v 1.22.4.2 2005/11/06 02:52:49 vkurland Exp $
+  $Id: iptAdvancedDialog.cpp,v 1.26 2006/03/16 05:38:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,6 +30,7 @@
 
 #include "iptAdvancedDialog.h"
 #include "SimpleTextEditor.h"
+#include "ObjectManipulator.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -200,6 +201,7 @@ void iptAdvancedDialog::accept()
     pis->setCommand( installScript->text().latin1() );
     pis->setArguments( installScriptArgs->text().latin1() );
     
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
     iptAdvancedDialog_q::accept();
 }
 
