@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp,v 1.112 2006/09/08 05:43:59 vkurland Exp $
+  $Id: main.cpp,v 1.118 2006/10/22 18:20:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,6 +41,7 @@
 #include <qtextcodec.h>
 #include <qtooltip.h>
 #include <qtimer.h>
+#include <qpixmapcache.h>
 
 /*
 #ifdef _WIN32
@@ -591,11 +592,15 @@ int main( int argc, char ** argv )
     
         st = new FWBSettings();
 
+        if (fwbdebug) qDebug("creating pixmap factory ...");
+
 /* initialize preferences */
         st->init();
 
         if (fwbdebug) qDebug("done");
-    
+
+        QPixmapCache::setCacheLimit(4096);
+
 #ifdef ELC
         registered=init2(argv0, "Firewall Builder","fwb_gui","FirewallBuilder/2.1",true,true);
 #endif
