@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newHostDialog.cpp,v 1.11 2006/08/09 08:21:07 vkurland Exp $
+  $Id: newHostDialog.cpp,v 1.12 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,6 +57,7 @@
 #include <qregexp.h>
 #include <qapplication.h>
 #include <qcursor.h>
+#include <qpixmapcache.h>
 
 #include <iostream>
 
@@ -345,7 +346,7 @@ void newHostDialog::selected(const QString &title)
         list<FWObject*> fl;
         findHosts(tlib, fl, false);
 
-        QString icn_filename = QString( Resources::global_res->getObjResourceStr(fl.front(), "icon-tree").c_str() );
+        QString icn = QString( Resources::global_res->getObjResourceStr(fl.front(), "icon-tree").c_str() );
 
         templateList->clear();
 
@@ -353,8 +354,15 @@ void newHostDialog::selected(const QString &title)
         for (list<FWObject*>::iterator m=fl.begin(); m!=fl.end(); m++,n++)
         {
             FWObject *o=*m;
-            templateList->insertItem(QPixmap::fromMimeSource( icn_filename ),
-                                     o->getName().c_str() );
+
+            QPixmap pm;
+            if ( ! QPixmapCache::find( icn, pm) )
+            {
+                pm = QPixmap::fromMimeSource( icn );
+                QPixmapCache::insert( icn, pm);
+            }
+
+            templateList->insertItem(pm, o->getName().c_str() );
             templates[ templateList->item( templateList->count()-1 ) ]=o;
         }
         templateList->setCurrentItem(0);
