@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pfAdvancedDialog.cpp,v 1.19 2006/03/16 05:38:14 vkurland Exp $
+  $Id: pfAdvancedDialog.cpp,v 1.20 2006/09/28 23:36:29 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -176,6 +176,12 @@ pfAdvancedDialog::pfAdvancedDialog(QWidget *parent,FWObject *o)
     installScriptArgs->setText( pis->getArguments().c_str() );
 
 /* page "Prolog/Epilog" */
+
+    slm = getPrologPlaces( obj->getStr("platform").c_str() );
+    prologPlace->clear();
+    prologPlace->insertStringList(getScreenNames(slm));
+    data.registerOption( prologPlace,       fwopt,   "prolog_place", slm); 
+
     data.registerOption( prolog_script    , fwopt,   "prolog_script"  );
     data.registerOption( epilog_script    , fwopt,   "epilog_script"  );
 
