@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pixAdvancedDialog.cpp,v 1.26 2006/05/15 04:26:33 vkurland Exp $
+  $Id: pixAdvancedDialog.cpp,v 1.29 2006/10/21 06:35:12 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -86,15 +86,16 @@ pixAdvancedDialog::pixAdvancedDialog(QWidget *parent,FWObject *o)
  */
 #if defined(Q_OS_WIN32) ||  defined(Q_OS_MACX)
 
-    if ( ! QFile::exists( compiler ) )
+    if ( ! QFile::exists( compiler.c_str() ) )
     {
-        QString cmppath = st->getStr( QString("Compilers/")+compiler );
+        string ts = string("Compilers/")+compiler;
+        QString cmppath = st->getStr( ts.c_str() );
         if (!cmppath.isEmpty()) compiler=cmppath.latin1();
         else
         {
             /* try to find compiler in appRootDir. */
-
-            if ( QFile::exists( appRootDir + FS_SEPARATOR + compiler ) )
+            string ts =  appRootDir + FS_SEPARATOR + compiler;
+            if ( QFile::exists( ts.c_str() ) )
                 compiler = appRootDir + FS_SEPARATOR + compiler;
         }
     }
@@ -237,7 +238,11 @@ pixAdvancedDialog::pixAdvancedDialog(QWidget *parent,FWObject *o)
 
     bool outboundACLSupported= (Resources::platform_res[platform]->getResourceBool(
                   "/FWBuilderResources/Target/options/"+vers+"/pix_outbound_acl_supported") );
-    pix_emulate_out_acl->setEnabled(!outboundACLSupported);
+
+    if (outboundACLSupported)
+        pix_emulate_out_acl->hide();
+    else
+        pix_generate_out_acl->hide();
 
     data.registerOption( outputFileName       , fwoptions,
                          "output_file"  );
@@ -251,6 +256,9 @@ pixAdvancedDialog::pixAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( pix_emulate_out_acl  , fwoptions,  
                          "pix_emulate_out_acl" );
 
+    data.registerOption( pix_generate_out_acl  , fwoptions,  
+                         "pix_generate_out_acl" );
+
 
     data.registerOption( pix_acl_basic , fwoptions,  
                          "pix_acl_basic" );
