@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp,v 1.33 2006/09/17 18:58:12 vkurland Exp $
+  $Id: platforms.cpp,v 1.35 2006/10/24 03:43:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -48,7 +48,8 @@ QStringList logLevels;
 QStringList logFacilities;
 QStringList actionsOnReject;
 QStringList routeOptions_pf_ipf;
-QStringList prologPlaces;
+QStringList prologPlaces_ipt;
+QStringList prologPlaces_pf;
 QStringList limitSuffixes;
 
 void init_platforms()
@@ -140,12 +141,27 @@ void init_platforms()
     routeOptions_pf_ipf.push_back(QObject::tr("Route a copy through"));
     routeOptions_pf_ipf.push_back("route_copy_through");
     
-    prologPlaces.push_back(QObject::tr("on top of the script"));
-    prologPlaces.push_back("top");
-    prologPlaces.push_back(QObject::tr("after interface configuration"));
-    prologPlaces.push_back("after_interfaces");
-    prologPlaces.push_back(QObject::tr("after policy reset"));
-    prologPlaces.push_back("after_flush");
+    prologPlaces_ipt.push_back(QObject::tr("on top of the script"));
+    prologPlaces_ipt.push_back("top");
+    prologPlaces_ipt.push_back(QObject::tr("after interface configuration"));
+    prologPlaces_ipt.push_back("after_interfaces");
+    prologPlaces_ipt.push_back(QObject::tr("after policy reset"));
+    prologPlaces_ipt.push_back("after_flush");
+    
+    prologPlaces_pf.push_back(QObject::tr("in the activation shell script"));
+    prologPlaces_pf.push_back("fw_file");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, at the very top"));
+    prologPlaces_pf.push_back("pf_file_top");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after set comamnds"));
+    prologPlaces_pf.push_back("pf_file_after_set");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after scrub comamnds"));
+    prologPlaces_pf.push_back("pf_file_after_scrub");
+
+    prologPlaces_pf.push_back(QObject::tr("in the pf rule file, after table definitions"));
+    prologPlaces_pf.push_back("pf_file_after_tables");
     
     limitSuffixes.push_back("");
     limitSuffixes.push_back("");
@@ -379,17 +395,32 @@ const QStringList& getActionsOnReject(const QString &platform)
     return actionsOnReject;
 }
 
-const QStringList& getRouteOptions(const QString &platform)
+/*
+ *  need to return mapping list for the parameter 'route_option' of
+ *  action 'Routing' regardless of the firewall platform even though
+ *  it only makes sense and is needed for pf and ipf. This is because
+ *  ActionsDialog is designed with widget stack and therefore must
+ *  always initialize widgets for all platforms. Worse, it always
+ *  saves all parameters into rule options object, regardless of the
+ *  platform. So, if we return an empty mapping list from this method
+ *  because platform is not pf or ipf while user is editing action
+ *  parameters for iptables, parameters for pf and ipf get saved
+ *  uninitizalized and unmapped. QComboBox::currentText() returns the
+ *  first item which goes straight into rule options object. This is
+ *  ok in English locale, but breaks XML if the item has been
+ *  translated and the program runs under national locale. Sigh.
+ */
+const QStringList& getRouteOptions_pf_ipf(const QString &platform)
 {
-    if (platform=="pf" || platform=="ipf")
-        return routeOptions_pf_ipf;
-    else
-        return emptyList;
+    return routeOptions_pf_ipf;
 }
 
 const QStringList& getPrologPlaces(const QString &platform)
 {
-    return prologPlaces;
+    if (platform=="pf")
+        return prologPlaces_pf;
+    else
+        return prologPlaces_ipt;
 }
 
 const QStringList& getLimitSuffixes(const QString &platform)
