@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.h,v 1.10 2006/06/17 21:26:22 vkurland Exp $
+  $Id: platforms.h,v 1.11 2006/10/24 03:43:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -80,7 +80,7 @@ const QStringList& getActionsOnReject(const QString &platform);
  * returns a list of options for Route action
  * 
  */
-const QStringList& getRouteOptions(const QString &platform);
+const QStringList& getRouteOptions_pf_ipf(const QString &platform);
 
 /**
  * returns a list of Prolog places (mapping list)
