@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.cpp,v 1.48 2006/08/26 17:11:28 vkurland Exp $
+  $Id: utils.cpp,v 1.51 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -37,6 +37,7 @@
 #include <qdns.h>
 #include <qhostaddress.h>
 #include <qapplication.h>
+#include <qpixmapcache.h>
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/FWReference.h"
@@ -89,7 +90,12 @@ int addPopupMenuItem(QObject *res,
     icn = Resources::global_res->getResourceStr(resourceIconPath.latin1());
     if(icn!="")
     {
-        pm = QPixmap::fromMimeSource( icn.c_str() );
+//        pm = QPixmap::fromMimeSource( icn.c_str() );
+        if ( ! QPixmapCache::find( icn.c_str(), pm) )
+        {
+            pm = QPixmap::fromMimeSource( icn.c_str() );
+            QPixmapCache::insert( icn.c_str(), pm);
+        }
         itmID = menu->insertItem( pm, itemName , res , member, accel );
     } else
         itmID = menu->insertItem( itemName , res , member, accel);
@@ -421,19 +427,20 @@ QString getNameByAddr(const QString &addr)
     if (nlist.empty()) return "";
     return nlist.front();
 }
+
 QString wordWrap(const QString& s, int maxchinline)
 {
     int chcount=0;
     int lastwdpos=0;
     int linestart=0;
     bool fl_wd=true;
-    int pos=0;
+    unsigned int pos=0;
     QString res="";
     QChar ch;
     
-    for (;pos < s.length ();pos++,chcount++ )
+    for ( ; pos < s.length(); pos++,chcount++)
     {
-        ch=s[pos];
+        ch = s.at(pos);
         if (!ch.isLetter() && !ch.isNumber())
         {
             fl_wd=false;
@@ -465,7 +472,7 @@ QString wordWrap(const QString& s, int maxchinline)
             else
             {
                 res.append(s.mid(linestart,pos-linestart));
-                while (++pos< s.length() && s[pos].isSpace());
+                while (++pos< s.length() && s.at(pos).isSpace());
                 if (pos<s.length())
                 {
                     linestart=pos--;
