@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp,v 1.23 2006/06/05 04:53:21 vkurland Exp $
+  $Id: NATCompiler_ipt.cpp,v 1.25 2006/09/11 00:41:09 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -154,7 +154,6 @@ int NATCompiler_ipt::prolog()
 	    throw FWException(_("At least one interface should be marked as external, can not configure NAT"));
     }
 
-
     return n;
 }
 
@@ -189,8 +188,9 @@ void NATCompiler_ipt::_expandInterface(Interface *iface,
         IPv4 *ipv4=IPv4::cast(*j);
         if (ipv4!=NULL && use_mac && pa!=NULL)
         {
-            combinedAddress *ca=new combinedAddress();
+            combinedAddress *ca=new combinedAddress(dbcopy,true);
             dbcopy->add(ca);
+            dbcopy->addToIndex(ca);
             cacheObj(ca);
             ca->setName( "CA("+iface->getName()+")" );
             ca->setAddress( ipv4->getAddress() );
@@ -251,7 +251,7 @@ bool NATCompiler_ipt::ConvertLoadBalancingRules::processNext()
             a1= *j;
         }
 
-        AddressRange *ar= AddressRange::cast(compiler->dbcopy->create(AddressRange::TYPENAME,true) );
+        AddressRange *ar= AddressRange::cast(compiler->dbcopy->create(AddressRange::TYPENAME) );
         ar->setRangeStart( al.front() );
         ar->setRangeEnd( al.back() );
         ar->setName(string("%")+al.front().toString()+"-"+al.back().toString()+"%" );
@@ -290,7 +290,7 @@ bool NATCompiler_ipt::splitSDNATRule::processNext()
 
 /* first rule translates destination and may translate service (depends
  * on the original rule) */
-        NATRule *r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME,false) );
+        NATRule *r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
         r->setRuleType(NATRule::Unknown);
@@ -304,7 +304,7 @@ bool NATCompiler_ipt::splitSDNATRule::processNext()
 /* the second rule translates source and uses translated object in
  * ODst. Since the service could have been translated by the first
  * rule, we use TSrv in OSrv */
-        r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME,false) );
+        r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
         r->setRuleType(NATRule::Unknown);
@@ -497,7 +497,7 @@ bool NATCompiler_ipt::convertToAtomicportForOSrv::processNext()
         for (FWObject::iterator i1=osrv->begin(); i1!=osrv->end(); ++i1) 
         {
             NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                compiler->dbcopy->create(NATRule::TYPENAME) );
             r->duplicate(rule);
             compiler->temp_ruleset->add(r);
 
@@ -567,7 +567,7 @@ bool NATCompiler_ipt::splitOnODst::processNext()
 	    Address *a=Address::cast( o );
 	    assert(a);
 
-	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	    compiler->temp_ruleset->add(r);
 	    r->duplicate(rule);
 	    RuleElementODst *nodst=r->getODst();
@@ -598,7 +598,7 @@ bool NATCompiler_ipt::splitOnOSrv::processNext()
 	    Service *s=Service::cast( o );
 	    assert(s);
 
-	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	    compiler->temp_ruleset->add(r);
 	    r->duplicate(rule);
 	    RuleElementOSrv *nosrv=r->getOSrv();
@@ -696,7 +696,7 @@ bool NATCompiler_ipt::splitRuleIfRuleElementIsDynamicInterface::processNext()
 	    cl.push_back(o);   // can not remove right now because remove invalidates iterator
             nre--;
 
-	    NATRule  *new_rule= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	    NATRule  *new_rule= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	    compiler->temp_ruleset->add(new_rule);
 	    new_rule->duplicate(rule);
             RuleElement *new_re=RuleElement::cast(new_rule->getFirstByType(re_type));
@@ -969,7 +969,7 @@ bool NATCompiler_ipt::splitMultiSrcAndDst::processNext()
 // get old chain name create new chain name
         string new_chain=NATCompiler_ipt::getNewTmpChainName(rule);
 // create new rule
-        NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+        NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
         compiler->temp_ruleset->add(r);
         r->duplicate(rule); 
 // move existing rule onto new chain
@@ -1047,6 +1047,7 @@ void NATCompiler_ipt::checkForDynamicInterfacesOfOtherObjects::findDynamicInterf
                                                                                      Rule        *rule)
 {
     if (re->isAny()) return;
+
     list<FWObject*> cl;
     for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
     {
@@ -1057,6 +1058,15 @@ void NATCompiler_ipt::checkForDynamicInterfacesOfOtherObjects::findDynamicInterf
 
         if (ifs!=NULL && ifs->isDyn() && ! ifs->isChildOf(compiler->fw))        
         {
+#if 0
+            cerr << "NATCompiler_ipt::checkForDynamicInterfacesOfOtherObjects" << endl;
+            cerr << "ifs: " << endl;
+            ifs->dump(true,true);
+            cerr << endl;
+            cerr << "fw: " << endl;
+            compiler->fw->dump(true,true);
+            cerr << endl;
+#endif
             char errstr[2048];
             sprintf(errstr,_("Can not build rule using dynamic interface '%s' of the object '%s' because its address in unknown. Rule %s"),
                     ifs->getName().c_str(), 
@@ -1114,7 +1124,7 @@ bool NATCompiler_ipt::splitServices::processNext()
 	list<Service*> &sl=(*i).second;
 
 	NATRule *r= NATRule::cast(
-	    compiler->dbcopy->create(NATRule::TYPENAME,false) );
+	    compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	RuleElementOSrv *nsrv=r->getOSrv();
@@ -1160,7 +1170,7 @@ bool NATCompiler_ipt::separatePortRanges::processNext()
 
             if (srs!=sre || drs!=dre) {
                 NATRule *r= NATRule::cast(
-                    compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                    compiler->dbcopy->create(NATRule::TYPENAME) );
                 compiler->temp_ruleset->add(r);
                 r->duplicate(rule);
                 RuleElementOSrv *nsrv=r->getOSrv();
@@ -1213,7 +1223,7 @@ bool NATCompiler_ipt::separateSourcePorts::processNext()
                 if (rule_4_src_ports==NULL)
                 {
                     rule_4_src_ports= NATRule::cast(
-                        compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                        compiler->dbcopy->create(NATRule::TYPENAME) );
                     compiler->temp_ruleset->add(rule_4_src_ports);
                     rule_4_src_ports->duplicate(rule);
                     nsrv=rule_4_src_ports->getOSrv();
@@ -1271,7 +1281,7 @@ bool NATCompiler_ipt::separateSourceAndDestinationPorts::processNext()
                 if (nrule==NULL)
                 {
                     nrule= NATRule::cast(
-                        compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                        compiler->dbcopy->create(NATRule::TYPENAME) );
                     compiler->temp_ruleset->add(nrule);
                     nrule->duplicate(rule);
                     nsrv=nrule->getOSrv();
@@ -1330,7 +1340,7 @@ bool NATCompiler_ipt::prepareForMultiport::processNext()
 		if (n==0) 
                 {
 		    r= NATRule::cast(
-			compiler->dbcopy->create(NATRule::TYPENAME,false) );
+			compiler->dbcopy->create(NATRule::TYPENAME) );
 		    compiler->temp_ruleset->add(r);
 		    r->duplicate(rule);
 		    nsrv=r->getOSrv();
@@ -1375,7 +1385,7 @@ bool NATCompiler_ipt::splitMultipleICMP::processNext()
             Service *s=Service::cast( o );
             assert(s);
 
-            r= NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            r= NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME) );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             nsrv=r->getOSrv();
@@ -1417,7 +1427,7 @@ bool NATCompiler_ipt::doOSrcNegation::processNext()
  * TMP_CHAIN   A   any  any   RETURN     RETURN
  * TMP_CHAIN  any  any   C   SNAT/DNAT  ---------
  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();  nsrc->clearChildren();  nsrc->setAnyElement();
@@ -1429,7 +1439,7 @@ bool NATCompiler_ipt::doOSrcNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   A  any  any  RETURN  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	ndst=r->getODst();   ndst->clearChildren();   ndst->setAnyElement();
@@ -1447,7 +1457,7 @@ bool NATCompiler_ipt::doOSrcNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   any any C  ACTION  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();  nsrc->clearChildren();  nsrc->setAnyElement();
@@ -1495,7 +1505,7 @@ bool NATCompiler_ipt::doODstNegation::processNext()
  * TMP_CHAIN  any   B   any   RETURN     RETURN
  * TMP_CHAIN  any  any   C    SNAT/DNAT  ---------
  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	ndst=r->getODst();   ndst->clearChildren();   ndst->setAnyElement();
@@ -1507,7 +1517,7 @@ bool NATCompiler_ipt::doODstNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   any  B  any  RETURN  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();   nsrc->clearChildren();   nsrc->setAnyElement();
@@ -1525,7 +1535,7 @@ bool NATCompiler_ipt::doODstNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   any  any  C  ACTION  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();  nsrc->clearChildren();  nsrc->setAnyElement();
@@ -1572,7 +1582,7 @@ bool NATCompiler_ipt::doOSrvNegation::processNext()
  * TMP_CHAIN  any  any   C    RETURN     RETURN
  * TMP_CHAIN  any  any  any   SNAT/DNAT  ---------
  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrv=r->getOSrv();  nsrv->clearChildren();  nsrv->setAnyElement();
@@ -1584,7 +1594,7 @@ bool NATCompiler_ipt::doOSrvNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   any  any  C  RETURN  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();  nsrc->clearChildren();  nsrc->setAnyElement();
@@ -1601,7 +1611,7 @@ bool NATCompiler_ipt::doOSrvNegation::processNext()
 	tmp_queue.push_back(r);
 
 /* TMP_CHAIN   any  any  any  ACTION  */
-	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrc=r->getOSrc();  nsrc->clearChildren();  nsrc->setAnyElement();
@@ -1636,7 +1646,7 @@ bool NATCompiler_ipt::splitNONATRule::processNext()
  * both these chains because there may be other rules in POSTROUTING
  * chain that may accidentally match the packet and translate it.
  */
-        NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+        NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
         compiler->temp_ruleset->add(r);
         r->duplicate(rule);
         r->setStr("ipt_chain","POSTROUTING");  
@@ -1723,7 +1733,7 @@ bool NATCompiler_ipt::splitIfOSrcAny::processNext()
 
         if (osrc->isAny())
         {
-            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             RuleElementOSrc *nosrcrel=r->getOSrc();
@@ -1905,7 +1915,7 @@ bool NATCompiler_ipt::AssignInterface::processNext()
         for (list<string>::iterator i=regular_interfaces.begin(); i!=regular_interfaces.end(); i++)
         {
             NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                compiler->dbcopy->create(NATRule::TYPENAME) );
             r->duplicate(rule);
             compiler->temp_ruleset->add(r);
 
@@ -2052,7 +2062,7 @@ bool NATCompiler_ipt::processMultiAddressObjectsInRE::processNext()
         for (list<MultiAddressRunTime*>::iterator i=cl.begin(); i!=cl.end(); i++)
         {
             MultiAddressRunTime *atrt = *i;
-            r = NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            r = NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             nre=RuleElement::cast( r->getFirstByType(re_type) );
@@ -2080,8 +2090,14 @@ void NATCompiler_ipt::compile()
     try {
 
 	Compiler::compile();
-
+#if 0
+        cerr << "Checking objects" << endl;
+        dbcopy->findInIndex("id45035B9F499")->dump(true,true);
+        dbcopy->findInIndex("id4504CDCF27596")->dump(true,true);
+        cerr << endl;
+#endif
         add( new NATCompiler::Begin());
+
         add( new printTotalNumberOfRules(                                  ));
 
         add( new recursiveGroupsInOSrc("check for recursive groups in OSRC"));
@@ -2092,7 +2108,6 @@ void NATCompiler_ipt::compile()
         add( new recursiveGroupsInTDst("check for recursive groups in TDST"));
         add( new recursiveGroupsInTSrv("check for recursive groups in TSRV"));
 
-
         add( new emptyGroupsInOSrc("check for empty groups in OSRC"      ));
         add( new emptyGroupsInODst("check for empty groups in ODST"      ));
         add( new emptyGroupsInOSrv("check for empty groups in OSRV"      ));
@@ -2101,7 +2116,6 @@ void NATCompiler_ipt::compile()
         add( new emptyGroupsInTDst("check for empty groups in TDST"      ));
         add( new emptyGroupsInTSrv("check for empty groups in TSRV"      ));
 
-
 	add( new ExpandGroups(            "Expand groups"                ));
         add( new eliminateDuplicatesInOSRC("eliminate duplicates in OSRC"));
         add( new eliminateDuplicatesInODST("eliminate duplicates in ODST"));
@@ -2154,7 +2168,7 @@ void NATCompiler_ipt::compile()
 
         add( new ExpandMultipleAddresses("expand multiple addresses") );
 
-        add( new specialCaseWithUnnumberedInterface("check for a special cases with dynamic and unnumbered interfaces" ) );
+        add( new specialCaseWithUnnumberedInterface("check for special cases with dynamic and unnumbered interfaces" ) );
         add( new checkForDynamicInterfacesOfOtherObjects( "check for dynamic interfaces of other hosts and firewalls" ) );
 
         add( new verifyRuleWithMAC("verify rules using MAC address filtering"));
