@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.27.4.1 2006/03/27 04:41:46 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp,v 1.35 2006/05/16 22:39:59 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,6 +35,7 @@
 #include "fwbuilder/Network.h"
 #include "fwbuilder/Address.h"
 #include "fwbuilder/Resources.h"
+#include "fwbuilder/MultiAddress.h"
 
 #ifndef _WIN32
 #  include <unistd.h>
@@ -192,6 +193,8 @@ void OSConfigurator_linux24::processFirewallOptions()
 
 void OSConfigurator_linux24::addVirtualAddressForNAT(const Network *nw)
 {
+    ostringstream  ostr;
+
     FWOptions* options=fw->getOptionsObject();
     if ( options->getBool("manage_virtual_addr") ) 
     {
@@ -212,57 +215,41 @@ void OSConfigurator_linux24::addVirtualAddressForNAT(const Network *nw)
                 a      = n.getBroadcastAddress() -1;
                 last   = a.toString();
 
-                output                                       << endl;
-                output << "incaddr()"                        << endl;
-                output << "{"                                << endl;
-                output << "  n1=$4"                          << endl;
-                output << "  n2=$3"                          << endl;
-                output << "  n3=$2"                          << endl;
-                output << "  n4=$1"                          << endl;
-                output                                       << endl;
-                output << "  vn1=`eval  \"echo \\\\$$n1\"`"  << endl;
-                output                                       << endl;
-                output << "  R=`expr $vn1 \\< 255`"          << endl;
-                output << "  if test $R = \"1\"; then"       << endl;
-                output << "    eval \"$n1=`expr $vn1 + 1`\"" << endl;
-                output << "  else"                           << endl;
-                output << "    eval \"$n1=0\""               << endl;
-                output << "    incaddr XX $n4 $n3 $n2"       << endl;
-                output << "  fi"                             << endl;
-                output << "}"                                << endl;
-                output                                       << endl;
+                ostr                                       << endl;
 
-                output << "a=\"" << first << "\""            << endl;
-                output << "while test \"$a\" != \"" << last << "\"; do" << endl;
+                ostr << "a=\"" << first << "\""            << endl;
+                ostr << "while test \"$a\" != \"" << last << "\"; do" << endl;
 
-                output << "  add_addr ${a} " << nw->getNetmask().getLength() << " "
+                ostr << "  add_addr ${a} " << nw->getNetmask().getLength() << " "
                        << iface->getName() << endl;
 
+                ostr                                       << endl;
+                ostr << "  OIFS=$IFS"                      << endl;
+                ostr << "  IFS=\".\""                      << endl;
+                ostr << "  set $a"                         << endl;
+                ostr << "  a4=$1"                          << endl;
+                ostr << "  a3=$2"                          << endl;
+                ostr << "  a2=$3"                          << endl;
+                ostr << "  a1=$4"                          << endl;
+                ostr << "  IFS=$OIFS"                      << endl;
+                ostr << "  incaddr a4 a3 a2 a1"            << endl;
+                ostr << "  a=$a4\".\"$a3\".\"$a2\".\"$a1"  << endl;
 
-                output                                       << endl;
-                output << "  OIFS=$IFS"                      << endl;
-                output << "  IFS=\".\""                      << endl;
-                output << "  set $a"                         << endl;
-                output << "  a4=$1"                          << endl;
-                output << "  a3=$2"                          << endl;
-                output << "  a2=$3"                          << endl;
-                output << "  a1=$4"                          << endl;
-                output << "  IFS=$OIFS"                      << endl;
-                output << "  incaddr a4 a3 a2 a1"            << endl;
-                output << "  a=$a4\".\"$a3\".\"$a2\".\"$a1"  << endl;
-
-                output << "done" << endl << endl;
+                ostr << "done" << endl << endl;
                 virtual_addresses.push_back(nw->getAddress());
-
+                registerVirtualAddressForNat();
             } else
                 warning(_("Can not add virtual address ") + nw->getAddress().toString() +
                         _(" (object ") + nw->getName() + ")" );
         }
+        commands_to_add_virtual_addresses.push_back(ostr.str());
     }
 }
 
 void OSConfigurator_linux24::addVirtualAddressForNAT(const Address *addr)
 {
+    ostringstream  ostr;
+
     FWOptions* options=fw->getOptionsObject();
     if ( options->getBool("manage_virtual_addr") ) 
     {
@@ -275,23 +262,58 @@ void OSConfigurator_linux24::addVirtualAddressForNAT(const Address *addr)
                 Interface *iface=Interface::cast(iaddr->getParent());
                 assert(iface!=NULL);
 
-                output << "add_addr " << addr->getAddress().toString() << " "
+                ostr << "add_addr " << addr->getAddress().toString() << " "
                        << iaddr->getNetmask().getLength() <<  " "
                        << iface->getName() << endl;
         
                 virtual_addresses.push_back(addr->getAddress());
+                registerVirtualAddressForNat();
             } else
                 warning(_("Can not add virtual address ") + addr->getAddress().toString() +
                         _(" (object ") + addr->getName() + ")" );
         }
+        commands_to_add_virtual_addresses.push_back(ostr.str());
         return;
     }
 }
 
-void  OSConfigurator_linux24::configureInterfaces()
+void OSConfigurator_linux24::printCommandsToAddVirtualAddressesForNAT()
+{
+    output << "# Add virtual addresses for NAT rules" << endl;
+
+    list<string>::iterator i;
+    for (i=commands_to_add_virtual_addresses.begin();
+         i!=commands_to_add_virtual_addresses.end(); ++i)
+        output << *i;
+
+    output << endl;
+}
+
+void OSConfigurator_linux24::registerMultiAddressObject(MultiAddressRunTime *at)
+{
+    address_table_objects[at->getName()] = at->getSourceName();
+}
+
+void OSConfigurator_linux24::printChecksForRunTimeMultiAddress()
+{
+    output << "# Using " << address_table_objects.size() << " address table files" << endl;
+
+    map<string,string>::iterator i;
+    for (i=address_table_objects.begin(); i!=address_table_objects.end(); ++i)
+    {
+        string at_name = i->first;
+        string at_file = i->second;
+        output << "check_file \"" + at_name + "\" \"" + at_file + "\"" << endl;
+    }
+    output << endl;
+}
+
+void OSConfigurator_linux24::configureInterfaces()
 {
     FWOptions* options=fw->getOptionsObject();
 
+    output << "# Configure interfaces" << endl;
+
 /*
  *  Remove all host static routes and "pub" ARP entries if we are going to 
  *  create new ones
@@ -304,6 +326,7 @@ void  OSConfigurator_linux24::configureInterfaces()
 	    Interface *interface_=Interface::cast(*i);
 	    if ( interface_->isDyn() ) continue;
 	    if ( interface_->isUnnumbered() ) continue;
+	    if ( interface_->isBridgePort() ) continue;
 	    if ( interface_->isLoopback() ) continue;
 
             output << "$IP -4 neigh flush dev " 
@@ -330,6 +353,7 @@ void  OSConfigurator_linux24::configureInterfaces()
 
             if (iface->isDyn()) continue;
             if (iface->isUnnumbered()) continue;
+	    if (iface->isBridgePort() ) continue;
 
             FWObjectTypedChildIterator j=iface->findByType(IPv4::TYPENAME);
             for ( ; j!=j.end(); ++j ) 
@@ -339,7 +363,8 @@ void  OSConfigurator_linux24::configureInterfaces()
                 output << "add_addr " << iaddr->getAddress().toString() << " "
                        << iaddr->getNetmask().getLength() << " "
                        << iface->getName() << endl;
-        
+// add to the table of virtual addresses so we won't generate code to
+// configure the same address if it is needed for NAT
                 virtual_addresses.push_back(iaddr->getAddress());
             }
             output << "$IP link set " << iface->getName() << " up" << endl;
@@ -373,62 +398,38 @@ void  OSConfigurator_linux24::configureInterfaces()
 
 int  OSConfigurator_linux24::prolog()
 {
-/*
- * print definitions for variables IPTABLES, IP, LOGGER. Some day we may
- * add a choice of distro in the GUI. Right now paths are either default
- * for a given distro, or custom strings entered by user in the GUI and stored
- * in firewall options.
- */
-    printPathForAllTools(DISTRO);
+    printShellFunctions();
 
 /*
  * Process firewall options, build OS network configuration script
  */
-    processFirewallOptions();
+//    processFirewallOptions();
 
     output << endl;
 
-    configureInterfaces();
+//    configureInterfaces();
 
     return 0;
 }
 
-void  OSConfigurator_linux24::printPathForAllTools(const string &os)
+void  OSConfigurator_linux24::printShellFunctions()
 {
     FWOptions* options=fw->getOptionsObject();
     
-    string s, path_lsmod, path_modprobe, path_iptables, path_iptables_restore, path_ip, path_logger;
-
-    s=options->getStr("linux24_path_lsmod");
-    if (!s.empty()) path_lsmod=s;
-    else            path_lsmod=os_data.getPathForTool(os,OSData::LSMOD);
-
-    s=options->getStr("linux24_path_modprobe");
-    if (!s.empty()) path_modprobe=s;
-    else            path_modprobe=os_data.getPathForTool(os,OSData::MODPROBE);
-
-    s=options->getStr("linux24_path_iptables");
-    if (!s.empty()) path_iptables=s;
-    else            path_iptables=os_data.getPathForTool(os,OSData::IPTABLES);
-
-    s=options->getStr("linux24_path_iptables_restore");
-    if (!s.empty()) path_iptables_restore=s;
-    else            path_iptables_restore=os_data.getPathForTool(os,OSData::IPTABLES_RESTORE);
-
-    s=options->getStr("linux24_path_ip");
-    if (!s.empty()) path_ip=s;
-    else            path_ip=os_data.getPathForTool(os,OSData::IP);
-
-    s=options->getStr("linux24_path_logger");
-    if (!s.empty()) path_logger=s;
-    else            path_logger=os_data.getPathForTool(os,OSData::LOGGER);
-
     output                                                      << endl;
     output << "log() {"                                         << endl;
     output << "  echo \"$1\""                                   << endl;
     output << "  test -x \"$LOGGER\" && $LOGGER -p info \"$1\"" << endl;
     output << "}"                                               << endl;
     output                                                      << endl;
+    
+    output << "check_file() {"                             << endl;
+    output << "  test -r \"$2\" || {"                      << endl;
+    output << "    echo \"Can not find file '$2' referenced by AddressTable object '$1'\"" << endl;
+    output << "    exit 1"                                 << endl;
+    output << "  }"                                        << endl;
+    output << "}"                                          << endl;
+    output                                                 << endl;
 
     output << "va_num=1"                                   << endl;
 
@@ -521,15 +522,25 @@ void  OSConfigurator_linux24::printPathForAllTools(const string &os)
     output << endl;
     output << endl;
 
-
-
-    output << "LSMOD=\""   +path_lsmod+"\"\n";
-    output << "MODPROBE=\""+path_modprobe+"\"\n";
-    output << "IPTABLES=\""+path_iptables+"\"\n";
-    output << "IPTABLES_RESTORE=\""+path_iptables_restore+"\"\n";
-    output << "IP=\""      +path_ip+"\"\n";
-    output << "LOGGER=\""  +path_logger+"\"\n";
-    output << endl;
+    output << "# increment ip address"                      << endl;
+    output << "incaddr()"                                   << endl;
+    output << "{"                                           << endl;
+    output << "  n1=$4"                                     << endl;
+    output << "  n2=$3"                                     << endl;
+    output << "  n3=$2"                                     << endl;
+    output << "  n4=$1"                                     << endl;
+    output                                                  << endl;
+    output << "  vn1=`eval  \"echo \\\\$$n1\"`"             << endl;
+    output                                                  << endl;
+    output << "  R=`expr $vn1 \\< 255`"                     << endl;
+    output << "  if test $R = \"1\"; then"                  << endl;
+    output << "    eval \"$n1=`expr $vn1 + 1`\""            << endl;
+    output << "  else"                                      << endl;
+    output << "    eval \"$n1=0\""                          << endl;
+    output << "    incaddr XX $n4 $n3 $n2"                  << endl;
+    output << "  fi"                                        << endl;
+    output << "}"                                           << endl;
+    output                                                  << endl;
 
 /* check if package iproute2 is installed, but do this only if
  * we really need /usr/sbin/ip 
@@ -546,17 +557,53 @@ void  OSConfigurator_linux24::printPathForAllTools(const string &os)
         output << "fi"                                   << endl;
     }
 
-#if 0
-    output << "check lsmod    $LSMOD"    << endl;
-    output << "check modprobe $MODPROBE" << endl;
-    output << "check iptables $IPTABLES" << endl;
-    output << "check iptables-restore $IPTABLES_RESTORE" << endl;
-    output << "check ip       $IP"       << endl;
-#endif
-
     output << endl;
 }
 
+string  OSConfigurator_linux24::printPathForAllTools(const string &os)
+{
+    string res;
+
+    FWOptions* options=fw->getOptionsObject();
+    
+    string s, path_lsmod, path_modprobe, path_iptables, path_iptables_restore, path_ip, path_logger;
+
+    s=options->getStr("linux24_path_lsmod");
+    if (!s.empty()) path_lsmod=s;
+    else            path_lsmod=os_data.getPathForTool(os,OSData::LSMOD);
+
+    s=options->getStr("linux24_path_modprobe");
+    if (!s.empty()) path_modprobe=s;
+    else            path_modprobe=os_data.getPathForTool(os,OSData::MODPROBE);
+
+    s=options->getStr("linux24_path_iptables");
+    if (!s.empty()) path_iptables=s;
+    else            path_iptables=os_data.getPathForTool(os,OSData::IPTABLES);
+
+    s=options->getStr("linux24_path_iptables_restore");
+    if (!s.empty()) path_iptables_restore=s;
+    else            path_iptables_restore=os_data.getPathForTool(os,OSData::IPTABLES_RESTORE);
+
+    s=options->getStr("linux24_path_ip");
+    if (!s.empty()) path_ip=s;
+    else            path_ip=os_data.getPathForTool(os,OSData::IP);
+
+    s=options->getStr("linux24_path_logger");
+    if (!s.empty()) path_logger=s;
+    else            path_logger=os_data.getPathForTool(os,OSData::LOGGER);
+
+
+    res += "LSMOD=\""   +path_lsmod+"\"\n";
+    res += "MODPROBE=\""+path_modprobe+"\"\n";
+    res += "IPTABLES=\""+path_iptables+"\"\n";
+    res += "IPTABLES_RESTORE=\""+path_iptables_restore+"\"\n";
+    res += "IP=\""      +path_ip+"\"\n";
+    res += "LOGGER=\""  +path_logger+"\"\n";
+    res += "\n";
+
+    return res;
+}
+
 void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
 {
     FWOptions* options=fw->getOptionsObject();
@@ -590,6 +637,86 @@ void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
     }
 }
 
+string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
+                                                     const string &command)
+{
+    string command_line = command;
+    ostringstream  res;
+    ostringstream  ext_command_line;
+
+    int nlines = 0;
+    string::size_type p1 = 0;
+    string::size_type p2, p3;
+
+    p1=command_line.find("$at_");
+    if ( p1!=string::npos )
+    {
+        p2=command_line.find(" ",p1);
+        string at_var= command_line.substr(p1+1,p2-p1-1);  // skip '$'
+        string atfile = rule->getStr("address_table_file");
+        ext_command_line << "grep -Ev '^#' " << atfile << " | ";
+        ext_command_line << "while read L ; do" << endl;
+        ext_command_line << "  set $L; " << at_var << "=$1; ";
+        ext_command_line << command_line;
+        ext_command_line << "done" << endl;
+
+        command_line = ext_command_line.str();
+    }
+
+    p1 = 0;
+    while (1)
+    {
+        p1=command_line.find_first_of("\n\r",p1);
+        if (p1==string::npos) break;
+        nlines++;
+        p1=command_line.find_first_not_of("\n\r",p1);
+        if (p1==string::npos) break;
+    }
+
+/* if anywhere in command_line we used variable holding an address of
+ * dynamic interface (named $i_something) then we need to add
+ * this command with a check for the value of this variable. We execute
+ * iptables command only if the value is a non-empty string.
+ */
+
+    p1=command_line.find("$i_");
+    string  iface_name;
+    string  iface_var;
+    if ( p1==string::npos ) return command_line;
+
+    p2=command_line.find(" ",p1);
+    p3=command_line.find("_",p1) +1;
+    iface_name=command_line.substr(p3,p2-p3);
+    iface_var= command_line.substr(p1,p2-p1);
+
+/* if interface name ends with '*', this is a wildcard interface. */
+    string::size_type p4;
+    if ((p4=iface_name.find("*"))!=string::npos)
+    {
+        string cmdline=command_line;
+        string iface_family_name=iface_name.substr(0,p4);
+        res << "getinterfaces " << iface_family_name << " | while read I; do" << endl;
+        res << "  ivar=`getInterfaceVarName $I`" << endl;
+        res << "  getaddr $I $ivar" << endl;
+        res << "  cmd=\"$\"$ivar"   << endl;
+        res << "  eval \"addr=$cmd\""          << endl;
+        cmdline.replace(p1,p2-p1,"$addr");
+        res << "  test -n \"$addr\" && ";
+        if (nlines>1) res << "{" << endl;
+        res << cmdline;
+        if (nlines>1) res << "}" << endl;
+        res << "done" << endl;
+    } else
+    {
+        res << "test -n \"" << iface_var << "\" && ";
+        if (nlines>1) res << "{" << endl;
+        res << command_line;
+        if (nlines>1) res << "}" << endl;
+    }
+
+    return res.str();
+}
+
 void OSConfigurator_linux24::epilog()
 {
     FWOptions* options=fw->getOptionsObject();
