@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp,v 1.30 2006/06/15 05:06:08 vkurland Exp $
+  $Id: PolicyCompiler_PrintRule.cpp,v 1.31 2006/11/10 05:47:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -333,13 +333,11 @@ string PolicyCompiler_ipt::PrintRule::_printDirectionAndInterface(PolicyRule *ru
 
     if (rule_iface->isBridgePort() && version == "1.3.0")
     {
-        ostr << " -m physdev ";
-
         if (rule->getDirection()==PolicyRule::Inbound)   
-            ostr << " --physdev-in "  << iface_name; 
+            ostr << " -m physdev --physdev-in "  << iface_name; 
 
         if (rule->getDirection()==PolicyRule::Outbound)  
-            ostr << " --physdev-out "  << iface_name; 
+            ostr << " -m physdev --physdev-out "  << iface_name; 
     } else
     {
         if (rule->getDirection()==PolicyRule::Inbound)   
