@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h,v 1.24 2006/09/21 06:29:43 vkurland Exp $
+  $Id: PolicyCompiler_ipt.h,v 1.25 2006/11/10 05:24:48 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -121,7 +121,15 @@ namespace fwcompiler {
 	/**
 	 * set target and chain in case of branching
 	 */
-        DECLARE_POLICY_RULE_PROCESSOR(Branching);
+        class Branching : public PolicyRuleProcessor
+        {
+            public:
+            Branching(const std::string &name) : PolicyRuleProcessor(name) {}
+            virtual bool processNext();
+            void expandBranch(libfwbuilder::PolicyRule *rule,
+                              const std::string &parentRuleNum );
+        };
+        friend class Branching;
 
 	/**
 	 * set target and chain in case of route rules
