@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: pf.cpp,v 1.34 2006/09/15 05:48:22 vkurland Exp $
+  $Id: pf.cpp,v 1.37 2006/10/19 04:20:13 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -95,6 +95,7 @@ static int              dl             = 0;
 static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
+static bool             test_mode      = false;
 
 static map<string,RuleSet*> branches;
 static map<string,string>   anchor_files;
@@ -133,6 +134,17 @@ string printTimeout(FWOptions* options,
     return res.str();
 }
 
+void printProlog(ofstream &file, const string &prolog_code)
+{
+    file << endl;
+    file << "#" << endl;
+    file << "# Prolog script" << endl;
+    file << "#" << endl;
+    file << prolog_code << endl;
+    file << "#" << endl;
+    file << "# End of prolog script" << endl;
+    file << "#" << endl;
+}
 
 int main(int argc, char * const *argv)
 {   
@@ -174,7 +186,9 @@ int main(int argc, char * const *argv)
             fw_file_name = string(optarg);
             break;
         case 'x':
-            if (*optarg=='p') {
+            if (*optarg=='t') {
+                test_mode = true;
+            } else if (*optarg=='p') {
                 ++optarg;
                 drp  = atoi(optarg);
             } else {
@@ -331,6 +345,10 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	string firewall_dir=options->getStr("firewall_dir");
 	if (firewall_dir=="") firewall_dir="/etc/fw";
 
+	string prolog_place = options->getStr("prolog_place");
+        if (prolog_place.empty()) prolog_place = "fw_file";  // old default
+        string pre_hook= fw->getOptionsObject()->getStr("prolog_script");
+
 	bool debug=options->getBool("debug");
 	string shell_dbg=(debug)?"-x":"" ;
 	string pfctl_dbg=(debug)?"-v ":"";
@@ -395,6 +413,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	n.setDebugLevel( dl );
 	n.setDebugRule(  drn );
 	n.setVerbose( verbose );
+        if (test_mode) n.setTestMode();
 
 	bool     have_nat=false;
 	if ( n.prolog() > 0 ) 
@@ -410,6 +429,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	c.setDebugLevel( dl );
 	c.setDebugRule(  drp );
 	c.setVerbose( verbose );
+        if (test_mode) c.setTestMode();
 
 	bool     have_pf=false;
 	if ( c.prolog() > 0 ) 
@@ -438,6 +458,9 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         pf_file.open(pf_file_name.c_str());
 #endif
 
+        if (prolog_place == "pf_file_top")
+            printProlog(pf_file, pre_hook);
+
         pf_file << endl;
 
         bool f1=(options->getBool("pf_do_limit_frags") &&
@@ -529,6 +552,9 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 
         pf_file << endl;
 
+        if (prolog_place == "pf_file_after_set")
+            printProlog(pf_file, pre_hook);
+
         string   scrub_options;
 
         if (options->getBool("pf_do_scrub"))
@@ -567,7 +593,14 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         }
         pf_file << endl;
 
+        if (prolog_place == "pf_file_after_scrub")
+            printProlog(pf_file, pre_hook);
+
         pf_file << table_factory->PrintTables();
+        pf_file << endl;
+
+        if (prolog_place == "pf_file_after_tables")
+            printProlog(pf_file, pre_hook);
 
 	if (have_nat)   pf_file << n.getCompiledScript();
         if (have_pf)    pf_file << c.getCompiledScript();
@@ -577,13 +610,13 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         // run policy compiler for each branch we have found in the
         // ruleset and store the result in a separate .conf file
         //
-        map<string,RuleSet*>::iterator i;
-        for (i=branches.begin(); i!=branches.end(); ++i)
+        map<string,RuleSet*>::iterator bi;
+        for (bi=branches.begin(); bi!=branches.end(); ++bi)
         {
             table_factory = new TableFactory();
 
-            string branchName = i->first;
-            RuleSet *subset = i->second;
+            string branchName = bi->first;
+            RuleSet *subset = bi->second;
             PolicyCompiler_pf c( objdb , fwobjectname , oscnf , &n, table_factory );
             c.setSourceRuleSet( subset );
             c.setRuleSetName(branchName);
@@ -591,6 +624,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             c.setDebugLevel( dl );
             c.setDebugRule(  drp );
             c.setVerbose( verbose );
+            if (test_mode) c.setTestMode();
 
             if ( c.prolog() > 0 ) 
             {
@@ -719,26 +753,8 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                 << "$PFCTL -F Sources" << endl
                 << "$PFCTL -F Tables" << endl;
 
-
-/*
- *  we add prolog and epilog to the activation shell script rather
- *  than to the .conf file. This is more flexible since user can
- *  execute some shell commands, as well as add any policy and/or nat
- *  rules by putting them into their .conf file and loading them from
- *  prolog or epilog script. Because of this, prolog is added after
- *  all rules are flushed.
- */ 
-        fw_file << endl;
-        fw_file << "#" << endl;
-        fw_file << "# Prolog script" << endl;
-        fw_file << "#" << endl;
-        
-        string pre_hook= fw->getOptionsObject()->getStr("prolog_script");
-        fw_file << pre_hook << endl;
-
-        fw_file << "#" << endl;
-        fw_file << "# End of prolog script" << endl;
-        fw_file << "#" << endl;
+        if (prolog_place == "fw_file")
+            printProlog(fw_file, pre_hook);
 
 	fw_file << endl;
 
