@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.cpp,v 1.15 2006/05/21 04:47:10 vkurland Exp $
+  $Id: NATCompiler_pf.cpp,v 1.17 2006/09/15 05:48:22 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -89,7 +89,7 @@ int NATCompiler_pf::prolog()
 
 /* pseudo-host with ip address 127.0.0.1  We'll use it for redirection NAT rules */
     //FWObject    *grp;
-    loopback_address=IPv4::cast(dbcopy->create(IPv4::TYPENAME,false) );
+    loopback_address=IPv4::cast(dbcopy->create(IPv4::TYPENAME) );
     loopback_address->setAddress("127.0.0.1");
     loopback_address->setName("__loopback_address__");
     loopback_address->setId("__loopback_address_id__");
@@ -186,7 +186,7 @@ bool NATCompiler_pf::splitSDNATRule::processNext()
 
 /* first rule translates destination and may translate service (depends
  * on the original rule) */
-        NATRule *r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME,false) );
+        NATRule *r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
         r->setRuleType(NATRule::Unknown);
@@ -200,7 +200,7 @@ bool NATCompiler_pf::splitSDNATRule::processNext()
 /* the second rule translates source and uses translated object in
  * ODst. Since the service could have been translated by the first
  * rule, we use TSrv in OSrv */
-        r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME,false) );
+        r = NATRule::cast( compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
         r->setRuleType(NATRule::Unknown);
@@ -339,7 +339,7 @@ bool NATCompiler_pf::splitOnOSrv::processNext()
 	    Service *s=Service::cast( o );
 	    assert(s);
 
-	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,true) );
+	    NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
 	    compiler->temp_ruleset->add(r);
 	    r->duplicate(rule);
 	    RuleElementOSrv *nosrv=r->getOSrv();
@@ -416,7 +416,7 @@ bool NATCompiler_pf::splitForTSrc::processNext()
             interfaceGroups[iface->getId()].push_back(o);
     }
 
-    if (interfaceGroups.size()==1) tmp_queue.push_back(rule);
+    if (interfaceGroups.size()<=1) tmp_queue.push_back(rule);
     else
     {
         map<string,list<FWObject*> >::iterator i;
@@ -426,7 +426,7 @@ bool NATCompiler_pf::splitForTSrc::processNext()
 
             RuleElementTSrc  *ntsrc = NULL;
             NATRule *r = NATRule::cast(
-                compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                compiler->dbcopy->create(NATRule::TYPENAME) );
             r->duplicate(rule);
             compiler->temp_ruleset->add(r);
                 
@@ -806,7 +806,7 @@ bool NATCompiler_pf::processMultiAddressObjectsInRE::processNext()
 
         for (FWObject::iterator i=cl.begin(); i!=cl.end(); i++)
         {
-            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            NATRule *r= NATRule::cast(compiler->dbcopy->create(NATRule::TYPENAME) );
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
             nre=RuleElement::cast( r->getFirstByType(re_type) );
