@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf.cpp,v 1.8 2006/05/17 02:30:18 vkurland Exp $
+  $Id: PolicyCompiler_ipf.cpp,v 1.10 2006/09/09 05:05:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -53,21 +53,21 @@ int PolicyCompiler_ipf::prolog()
     int n= PolicyCompiler_pf::prolog();
 
 //    FWObject    *grp;
-    anytcp=TCPService::cast(dbcopy->create(TCPService::TYPENAME,false) );
+    anytcp=TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
     anytcp->setId(ANY_TCP_OBJ_ID);
 //    grp=dbcopy->getById( dbcopy->std.TCPServicesId , true );
 //    assert(grp!=NULL);
     dbcopy->add(anytcp,false);
     cacheObj(anytcp); // to keep cache consistent
 
-    anyudp=UDPService::cast(dbcopy->create(UDPService::TYPENAME,false) );
+    anyudp=UDPService::cast(dbcopy->create(UDPService::TYPENAME) );
     anyudp->setId(ANY_UDP_OBJ_ID);
 //    grp=dbcopy->getById( dbcopy->std.UDPServicesId , true );
 //    assert(grp!=NULL);
     dbcopy->add(anyudp,false);
     cacheObj(anyudp); // to keep cache consistent
 
-    anyicmp=ICMPService::cast(dbcopy->create(ICMPService::TYPENAME,false) );
+    anyicmp=ICMPService::cast(dbcopy->create(ICMPService::TYPENAME) );
     anyicmp->setId(ANY_ICMP_OBJ_ID);
 //    grp=dbcopy->getById( dbcopy->std.ICMPServicesId , true );
 //    assert(grp!=NULL);
@@ -88,7 +88,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
     if (srv->isAny() && ! ruleopt->getBool("stateless") && rule->getAction()==PolicyRule::Accept) {
 
 	PolicyRule *r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	RuleElementSrv *nsrv=r->getSrv();
@@ -97,7 +97,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrv=r->getSrv();
@@ -106,7 +106,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	nsrv=r->getSrv();
@@ -115,7 +115,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
-	    compiler->dbcopy->create(PolicyRule::TYPENAME,true) );
+	    compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	FWOptions *ruleopt =r->getOptionsObject();
@@ -138,7 +138,7 @@ bool PolicyCompiler_ipf::doSrcNegation::processNext()
         RuleElementSrc *nsrc;
 	PolicyRule     *r;
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setAction(PolicyRule::Continue);
@@ -149,7 +149,7 @@ bool PolicyCompiler_ipf::doSrcNegation::processNext()
         r->setBool("skip_check_for_duplicates",true);
 	tmp_queue.push_back(r);
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         nsrc=r->getSrc();
@@ -176,7 +176,7 @@ bool PolicyCompiler_ipf::doDstNegation::processNext()
         RuleElementDst *ndst;
 	PolicyRule     *r;
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
 	r->setAction(PolicyRule::Continue);
@@ -187,7 +187,7 @@ bool PolicyCompiler_ipf::doDstNegation::processNext()
         r->setBool("skip_check_for_duplicates",true);
 	tmp_queue.push_back(r);
 
-	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME,false) );
+	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
 	r->duplicate(rule);
         ndst=r->getDst();
@@ -413,6 +413,10 @@ void PolicyCompiler_ipf::compile()
             add( new eliminateDuplicatesInSRC    ("eliminate duplicates in SRC"            ) );
             add( new eliminateDuplicatesInDST    ("eliminate duplicates in DST"            ) );
             add( new eliminateDuplicatesInSRV    ("eliminate duplicates in SRV"            ) );
+
+            add( new swapMultiAddressObjectsInSrc(" swap MultiAddress -> MultiAddressRunTime in Src") );
+            add( new swapMultiAddressObjectsInDst(" swap MultiAddress -> MultiAddressRunTime in Dst") );
+
             add( new ExpandMultipleAddressesInSRC("expand objects with multiple addresses in SRC" ) );
             add( new ExpandMultipleAddressesInDST("expand objects with multiple addresses in DST" ) );
             add( new ConvertToAtomic             ("convert to atomic rules"                ) );
