@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw.h,v 1.5 2006/08/31 16:14:29 vkurland Exp $
+  $Id: PolicyCompiler_ipfw.h,v 1.6 2006/10/07 06:42:44 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -68,6 +68,12 @@ namespace fwcompiler {
         virtual std::string debugPrintRule(libfwbuilder::Rule *rule);
         
 
+	/**
+	 * disabled rules with action Pipe, use this processor in the
+	 * run detecting rule shadowing
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(SpecialRuleActionsForShadowing);
+
 	/**
 	 * splits rules with service 'any' because ipf can keep state
 	 * only for UDP/TCP/ICMP
